from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SimplePropertyGraphProto(_message.Message):
    __slots__ = ("name", "name_path", "node_tables", "edge_tables", "labels", "property_declarations")
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    NODE_TABLES_FIELD_NUMBER: _ClassVar[int]
    EDGE_TABLES_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_DECLARATIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    name_path: _containers.RepeatedScalarFieldContainer[str]
    node_tables: _containers.RepeatedCompositeFieldContainer[SimpleGraphElementTableProto]
    edge_tables: _containers.RepeatedCompositeFieldContainer[SimpleGraphElementTableProto]
    labels: _containers.RepeatedCompositeFieldContainer[SimpleGraphElementLabelProto]
    property_declarations: _containers.RepeatedCompositeFieldContainer[SimpleGraphPropertyDeclarationProto]
    def __init__(self, name: _Optional[str] = ..., name_path: _Optional[_Iterable[str]] = ..., node_tables: _Optional[_Iterable[_Union[SimpleGraphElementTableProto, _Mapping]]] = ..., edge_tables: _Optional[_Iterable[_Union[SimpleGraphElementTableProto, _Mapping]]] = ..., labels: _Optional[_Iterable[_Union[SimpleGraphElementLabelProto, _Mapping]]] = ..., property_declarations: _Optional[_Iterable[_Union[SimpleGraphPropertyDeclarationProto, _Mapping]]] = ...) -> None: ...

class SimpleGraphElementTableProto(_message.Message):
    __slots__ = ("name", "property_graph_name_path", "kind", "input_table_name", "key_columns", "label_names", "property_definitions", "source_node_table", "dest_node_table", "dynamic_properties", "dynamic_label")
    class Kind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        KIND_UNSPECIFIED: _ClassVar[SimpleGraphElementTableProto.Kind]
        NODE: _ClassVar[SimpleGraphElementTableProto.Kind]
        EDGE: _ClassVar[SimpleGraphElementTableProto.Kind]
    KIND_UNSPECIFIED: SimpleGraphElementTableProto.Kind
    NODE: SimpleGraphElementTableProto.Kind
    EDGE: SimpleGraphElementTableProto.Kind
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_GRAPH_NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    INPUT_TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    KEY_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    LABEL_NAMES_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_DEFINITIONS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_NODE_TABLE_FIELD_NUMBER: _ClassVar[int]
    DEST_NODE_TABLE_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_LABEL_FIELD_NUMBER: _ClassVar[int]
    name: str
    property_graph_name_path: _containers.RepeatedScalarFieldContainer[str]
    kind: SimpleGraphElementTableProto.Kind
    input_table_name: str
    key_columns: _containers.RepeatedScalarFieldContainer[int]
    label_names: _containers.RepeatedScalarFieldContainer[str]
    property_definitions: _containers.RepeatedCompositeFieldContainer[SimpleGraphPropertyDefinitionProto]
    source_node_table: SimpleGraphNodeTableReferenceProto
    dest_node_table: SimpleGraphNodeTableReferenceProto
    dynamic_properties: SimpleGraphElementDynamicPropertiesProto
    dynamic_label: SimpleGraphElementDynamicLabelProto
    def __init__(self, name: _Optional[str] = ..., property_graph_name_path: _Optional[_Iterable[str]] = ..., kind: _Optional[_Union[SimpleGraphElementTableProto.Kind, str]] = ..., input_table_name: _Optional[str] = ..., key_columns: _Optional[_Iterable[int]] = ..., label_names: _Optional[_Iterable[str]] = ..., property_definitions: _Optional[_Iterable[_Union[SimpleGraphPropertyDefinitionProto, _Mapping]]] = ..., source_node_table: _Optional[_Union[SimpleGraphNodeTableReferenceProto, _Mapping]] = ..., dest_node_table: _Optional[_Union[SimpleGraphNodeTableReferenceProto, _Mapping]] = ..., dynamic_properties: _Optional[_Union[SimpleGraphElementDynamicPropertiesProto, _Mapping]] = ..., dynamic_label: _Optional[_Union[SimpleGraphElementDynamicLabelProto, _Mapping]] = ...) -> None: ...

class SimpleGraphElementLabelProto(_message.Message):
    __slots__ = ("name", "property_graph_name_path", "property_declaration_names")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_GRAPH_NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_DECLARATION_NAMES_FIELD_NUMBER: _ClassVar[int]
    name: str
    property_graph_name_path: _containers.RepeatedScalarFieldContainer[str]
    property_declaration_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., property_graph_name_path: _Optional[_Iterable[str]] = ..., property_declaration_names: _Optional[_Iterable[str]] = ...) -> None: ...

class SimpleGraphNodeTableReferenceProto(_message.Message):
    __slots__ = ("node_table_name", "edge_table_columns", "node_table_columns")
    NODE_TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    EDGE_TABLE_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    NODE_TABLE_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    node_table_name: str
    edge_table_columns: _containers.RepeatedScalarFieldContainer[int]
    node_table_columns: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, node_table_name: _Optional[str] = ..., edge_table_columns: _Optional[_Iterable[int]] = ..., node_table_columns: _Optional[_Iterable[int]] = ...) -> None: ...

class SimpleGraphPropertyDeclarationProto(_message.Message):
    __slots__ = ("name", "property_graph_name_path", "type")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_GRAPH_NAME_PATH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    property_graph_name_path: _containers.RepeatedScalarFieldContainer[str]
    type: _type_pb2.TypeProto
    def __init__(self, name: _Optional[str] = ..., property_graph_name_path: _Optional[_Iterable[str]] = ..., type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ...) -> None: ...

class SimpleGraphPropertyDefinitionProto(_message.Message):
    __slots__ = ("property_declaration_name", "value_expression_sql")
    PROPERTY_DECLARATION_NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_EXPRESSION_SQL_FIELD_NUMBER: _ClassVar[int]
    property_declaration_name: str
    value_expression_sql: str
    def __init__(self, property_declaration_name: _Optional[str] = ..., value_expression_sql: _Optional[str] = ...) -> None: ...

class SimpleGraphElementDynamicPropertiesProto(_message.Message):
    __slots__ = ("properties_expression",)
    PROPERTIES_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    properties_expression: str
    def __init__(self, properties_expression: _Optional[str] = ...) -> None: ...

class SimpleGraphElementDynamicLabelProto(_message.Message):
    __slots__ = ("label_expression",)
    LABEL_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    label_expression: str
    def __init__(self, label_expression: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/simple_property_graph.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/simple_property_graph.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)zetasql/proto/simple_property_graph.proto\x12\x07zetasql\x1a\x19zetasql/public/type.proto\"\xb7\x02\n\x18SimplePropertyGraphProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tname_path\x18\x02 \x03(\t\x12:\n\x0bnode_tables\x18\x03 \x03(\x0b\x32%.zetasql.SimpleGraphElementTableProto\x12:\n\x0b\x65\x64ge_tables\x18\x04 \x03(\x0b\x32%.zetasql.SimpleGraphElementTableProto\x12\x35\n\x06labels\x18\x05 \x03(\x0b\x32%.zetasql.SimpleGraphElementLabelProto\x12K\n\x15property_declarations\x18\x06 \x03(\x0b\x32,.zetasql.SimpleGraphPropertyDeclarationProto\"\xef\x04\n\x1cSimpleGraphElementTableProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18property_graph_name_path\x18\x02 \x03(\t\x12\x38\n\x04kind\x18\x03 \x01(\x0e\x32*.zetasql.SimpleGraphElementTableProto.Kind\x12\x18\n\x10input_table_name\x18\x04 \x01(\t\x12\x17\n\x0bkey_columns\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\x13\n\x0blabel_names\x18\x06 \x03(\t\x12I\n\x14property_definitions\x18\x07 \x03(\x0b\x32+.zetasql.SimpleGraphPropertyDefinitionProto\x12\x46\n\x11source_node_table\x18\x08 \x01(\x0b\x32+.zetasql.SimpleGraphNodeTableReferenceProto\x12\x44\n\x0f\x64\x65st_node_table\x18\t \x01(\x0b\x32+.zetasql.SimpleGraphNodeTableReferenceProto\x12M\n\x12\x64ynamic_properties\x18\n \x01(\x0b\x32\x31.zetasql.SimpleGraphElementDynamicPropertiesProto\x12\x43\n\rdynamic_label\x18\x0b \x01(\x0b\x32,.zetasql.SimpleGraphElementDynamicLabelProto\"0\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x08\n\x04NODE\x10\x01\x12\x08\n\x04\x45\x44GE\x10\x02\"r\n\x1cSimpleGraphElementLabelProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18property_graph_name_path\x18\x02 \x03(\t\x12\"\n\x1aproperty_declaration_names\x18\x03 \x03(\t\"}\n\"SimpleGraphNodeTableReferenceProto\x12\x17\n\x0fnode_table_name\x18\x01 \x01(\t\x12\x1e\n\x12\x65\x64ge_table_columns\x18\x02 \x03(\x05\x42\x02\x10\x01\x12\x1e\n\x12node_table_columns\x18\x03 \x03(\x05\x42\x02\x10\x01\"w\n#SimpleGraphPropertyDeclarationProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18property_graph_name_path\x18\x02 \x03(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\"e\n\"SimpleGraphPropertyDefinitionProto\x12!\n\x19property_declaration_name\x18\x01 \x01(\t\x12\x1c\n\x14value_expression_sql\x18\x02 \x01(\t\"I\n(SimpleGraphElementDynamicPropertiesProto\x12\x1d\n\x15properties_expression\x18\x01 \x01(\t\"?\n#SimpleGraphElementDynamicLabelProto\x12\x18\n\x10label_expression\x18\x01 \x01(\tB/\n\x12\x63om.google.zetasqlB\x19SimplePropertyGraphProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.simple_property_graph_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\031SimplePropertyGraphProtos'
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO'].fields_by_name['key_columns']._loaded_options = None
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO'].fields_by_name['key_columns']._serialized_options = b'\020\001'
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['edge_table_columns']._loaded_options = None
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['edge_table_columns']._serialized_options = b'\020\001'
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['node_table_columns']._loaded_options = None
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['node_table_columns']._serialized_options = b'\020\001'
  _globals['_SIMPLEPROPERTYGRAPHPROTO']._serialized_start=82
  _globals['_SIMPLEPROPERTYGRAPHPROTO']._serialized_end=393
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO']._serialized_start=396
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO']._serialized_end=1019
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO_KIND']._serialized_start=971
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO_KIND']._serialized_end=1019
  _globals['_SIMPLEGRAPHELEMENTLABELPROTO']._serialized_start=1021
  _globals['_SIMPLEGRAPHELEMENTLABELPROTO']._serialized_end=1135
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO']._serialized_start=1137
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO']._serialized_end=1262
  _globals['_SIMPLEGRAPHPROPERTYDECLARATIONPROTO']._serialized_start=1264
  _globals['_SIMPLEGRAPHPROPERTYDECLARATIONPROTO']._serialized_end=1383
  _globals['_SIMPLEGRAPHPROPERTYDEFINITIONPROTO']._serialized_start=1385
  _globals['_SIMPLEGRAPHPROPERTYDEFINITIONPROTO']._serialized_end=1486
  _globals['_SIMPLEGRAPHELEMENTDYNAMICPROPERTIESPROTO']._serialized_start=1488
  _globals['_SIMPLEGRAPHELEMENTDYNAMICPROPERTIESPROTO']._serialized_end=1561
  _globals['_SIMPLEGRAPHELEMENTDYNAMICLABELPROTO']._serialized_start=1563
  _globals['_SIMPLEGRAPHELEMENTDYNAMICLABELPROTO']._serialized_end=1626
# @@protoc_insertion_point(module_scope)



"""ZetaSQL Core Layer - WASI Communication & ProtoModel Infrastructure.

This package provides the foundational Layer 1 infrastructure:

API layer depend on this core infrastructure.
"""

from .exceptions import (
    ClientError,
    IllegalStateError,
    InvalidArgumentError,
    ServerError,
    StatusCode,
    ZetaSQLError,
)
from .local_service import ZetaSqlLocalService
from .wasm_client import WasmClient

__all__ = [
    "ClientError",
    "IllegalStateError",
    "InvalidArgumentError",
    "ServerError",
    "StatusCode",
    "WasmClient",
    "ZetaSQLError",
    "ZetaSqlLocalService",
]



"""
TypeFactory - Factory methods for creating ZetaSQL Type objects

This module provides Java-style factory methods for creating Type ProtoModel objects,
offering a clean alternative to manual protobuf construction.

Examples:
    >>> from zetasql.api import TypeFactory
    >>> from zetasql.types import TypeKind
    >>>
    >>> # Simple types
    >>> int_type = TypeFactory.create_simple_type(TypeKind.TYPE_INT64)
    >>>
    >>> # Array types
    >>> str_array = TypeFactory.create_array_type(
    ...     TypeFactory.create_simple_type(TypeKind.TYPE_STRING)
    ... )
    >>>
    >>> # Struct types
    >>> person_type = TypeFactory.create_struct_type([
    ...     ("id", TypeFactory.create_simple_type(TypeKind.TYPE_INT64)),
    ...     ("name", TypeFactory.create_simple_type(TypeKind.TYPE_STRING))
    ... ])
"""

from zetasql.types import ArrayType, MapType, StructField, StructType, Type, TypeKind


class TypeFactory:
    """Factory for creating ZetaSQL Type ProtoModel objects.

    All methods are static and return Type ProtoModel instances that can be
    used directly with builders or converted to protobuf via .to_proto().

    This API is inspired by the Java TypeFactory but adapted for Python's
    ProtoModel system.
    """

    @staticmethod
    def create_simple_type(type_kind: TypeKind | int) -> Type:
        """Create a simple (non-composite) type.

        Args:
            type_kind: TypeKind enum or integer type kind constant

        Returns:
            Type ProtoModel with the specified type_kind

        Examples:
            >>> int_type = TypeFactory.create_simple_type(TypeKind.TYPE_INT64)
            >>> str_type = TypeFactory.create_simple_type(TypeKind.TYPE_STRING)
            >>> bool_type = TypeFactory.create_simple_type(TypeKind.TYPE_BOOL)
        """
        return Type(type_kind=int(type_kind))

    @staticmethod
    def create_array_type(element_type: Type) -> Type:
        """Create an array type.

        Args:
            element_type: Type ProtoModel for the array elements

        Returns:
            Type ProtoModel representing ARRAY<element_type>

        Examples:
            >>> # ARRAY<STRING>
            >>> str_array = TypeFactory.create_array_type(
            ...     TypeFactory.create_simple_type(TypeKind.TYPE_STRING)
            ... )
            >>>
            >>> # ARRAY<ARRAY<INT64>> (nested arrays)
            >>> nested = TypeFactory.create_array_type(
            ...     TypeFactory.create_array_type(
            ...         TypeFactory.create_simple_type(TypeKind.TYPE_INT64)
            ...     )
            ... )
        """
        return Type(type_kind=TypeKind.TYPE_ARRAY, array_type=ArrayType(element_type=element_type))

    @staticmethod
    def create_struct_type(fields: list[tuple[str, Type]]) -> Type:
        """Create a struct type.

        Args:
            fields: List of (field_name, field_type) tuples

        Returns:
            Type ProtoModel representing STRUCT<fields>

        Examples:
            >>> # STRUCT<id INT64, name STRING>
            >>> person = TypeFactory.create_struct_type([
            ...     ("id", TypeFactory.create_simple_type(TypeKind.TYPE_INT64)),
            ...     ("name", TypeFactory.create_simple_type(TypeKind.TYPE_STRING))
            ... ])
            >>>
            >>> # Nested struct
            >>> order = TypeFactory.create_struct_type([
            ...     ("order_id", TypeFactory.create_simple_type(TypeKind.TYPE_INT64)),
            ...     ("customer", person)  # Use previously created struct
            ... ])
        """
        struct_fields = [StructField(field_name=name, field_type=field_type) for name, field_type in fields]
        return Type(type_kind=TypeKind.TYPE_STRUCT, struct_type=StructType(field=struct_fields))

    @staticmethod
    def create_map_type(key_type: Type, value_type: Type) -> Type:
        """Create a map type.

        Args:
            key_type: Type ProtoModel for map keys
            value_type: Type ProtoModel for map values

        Returns:
            Type ProtoModel representing MAP<key_type, value_type>

        Examples:
            >>> # MAP<STRING, INT64>
            >>> map_type = TypeFactory.create_map_type(
            ...     TypeFactory.create_simple_type(TypeKind.TYPE_STRING),
            ...     TypeFactory.create_simple_type(TypeKind.TYPE_INT64)
            ... )
        """
        return Type(type_kind=TypeKind.TYPE_MAP, map_type=MapType(key_type=key_type, value_type=value_type))


__all__ = ["TypeFactory"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/builtin_function.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/builtin_function.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%zetasql/public/builtin_function.proto\x12\x07zetasql*\xad\x8a\x02\n\x13\x46unctionSignatureId\x12@\n3__FunctionSignatureId__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x16\x46N_INVALID_FUNCTION_ID\x10\x01\x12\x11\n\rFN_ADD_DOUBLE\x10\x02\x12\x10\n\x0c\x46N_ADD_INT64\x10\x04\x12\x11\n\rFN_ADD_UINT64\x10w\x12\x13\n\x0e\x46N_ADD_NUMERIC\x10\xf8\x01\x12\x16\n\x11\x46N_ADD_BIGNUMERIC\x10\x85\x02\x12\x16\n\x11\x46N_ADD_DATE_INT64\x10\x8a\x02\x12\x16\n\x11\x46N_ADD_INT64_DATE\x10\x8b\x02\x12\x1e\n\x19\x46N_ADD_TIMESTAMP_INTERVAL\x10\x98\x02\x12\x1e\n\x19\x46N_ADD_INTERVAL_TIMESTAMP\x10\x99\x02\x12\x19\n\x14\x46N_ADD_DATE_INTERVAL\x10\x9a\x02\x12\x19\n\x14\x46N_ADD_INTERVAL_DATE\x10\x9b\x02\x12\x1d\n\x18\x46N_ADD_DATETIME_INTERVAL\x10\x9c\x02\x12\x1d\n\x18\x46N_ADD_INTERVAL_DATETIME\x10\x9d\x02\x12\x1d\n\x18\x46N_ADD_INTERVAL_INTERVAL\x10\xa1\x02\x12\n\n\x06\x46N_AND\x10\x05\x12\x14\n\x10\x46N_CASE_NO_VALUE\x10\x06\x12\x16\n\x12\x46N_CASE_WITH_VALUE\x10\x07\x12\x14\n\x10\x46N_DIVIDE_DOUBLE\x10(\x12\x16\n\x11\x46N_DIVIDE_NUMERIC\x10\xfa\x01\x12\x19\n\x14\x46N_DIVIDE_BIGNUMERIC\x10\x87\x02\x12\x1d\n\x18\x46N_DIVIDE_INTERVAL_INT64\x10\xad\x02\x12\x0e\n\nFN_GREATER\x10k\x12\x1c\n\x17\x46N_GREATER_INT64_UINT64\x10\xde\x01\x12\x1c\n\x17\x46N_GREATER_UINT64_INT64\x10\xdf\x01\x12\x17\n\x13\x46N_GREATER_OR_EQUAL\x10l\x12%\n FN_GREATER_OR_EQUAL_INT64_UINT64\x10\xe0\x01\x12%\n FN_GREATER_OR_EQUAL_UINT64_INT64\x10\xe1\x01\x12\x0b\n\x07\x46N_LESS\x10i\x12\x19\n\x14\x46N_LESS_INT64_UINT64\x10\xe2\x01\x12\x19\n\x14\x46N_LESS_UINT64_INT64\x10\xe3\x01\x12\x14\n\x10\x46N_LESS_OR_EQUAL\x10j\x12\"\n\x1d\x46N_LESS_OR_EQUAL_INT64_UINT64\x10\xe4\x01\x12\"\n\x1d\x46N_LESS_OR_EQUAL_UINT64_INT64\x10\xe5\x01\x12\x0c\n\x08\x46N_EQUAL\x10*\x12\x1a\n\x15\x46N_EQUAL_INT64_UINT64\x10\xe6\x01\x12\x1a\n\x15\x46N_EQUAL_UINT64_INT64\x10\xe7\x01\x12\x1d\n\x18\x46N_STRING_ARRAY_LIKE_ANY\x10\xa3\x02\x12\x1d\n\x18\x46N_STRING_ARRAY_LIKE_ALL\x10\xa4\x02\x12\x12\n\x0e\x46N_STRING_LIKE\x10\x61\x12\x17\n\x12\x46N_STRING_LIKE_ANY\x10\xa5\x02\x12\x17\n\x12\x46N_STRING_LIKE_ALL\x10\xa6\x02\x12\x1b\n\x16\x46N_BYTE_ARRAY_LIKE_ANY\x10\xa7\x02\x12\x1b\n\x16\x46N_BYTE_ARRAY_LIKE_ALL\x10\xa8\x02\x12\x10\n\x0c\x46N_BYTE_LIKE\x10\x62\x12\x15\n\x10\x46N_BYTE_LIKE_ANY\x10\xa9\x02\x12\x15\n\x10\x46N_BYTE_LIKE_ALL\x10\xaa\x02\x12\x1b\n\x16\x46N_STRING_NOT_LIKE_ANY\x10\xae\x02\x12\x19\n\x14\x46N_BYTE_NOT_LIKE_ANY\x10\xaf\x02\x12!\n\x1c\x46N_STRING_ARRAY_NOT_LIKE_ANY\x10\xb0\x02\x12\x1f\n\x1a\x46N_BYTE_ARRAY_NOT_LIKE_ANY\x10\xb1\x02\x12\x1b\n\x16\x46N_STRING_NOT_LIKE_ALL\x10\xb2\x02\x12\x19\n\x14\x46N_BYTE_NOT_LIKE_ALL\x10\xb3\x02\x12!\n\x1c\x46N_STRING_ARRAY_NOT_LIKE_ALL\x10\xb4\x02\x12\x1f\n\x1a\x46N_BYTE_ARRAY_NOT_LIKE_ALL\x10\xb5\x02\x12\t\n\x05\x46N_IN\x10\x64\x12\x10\n\x0b\x46N_IN_ARRAY\x10\xdb\x01\x12\x0e\n\nFN_BETWEEN\x10n\x12#\n\x1e\x46N_BETWEEN_INT64_UINT64_UINT64\x10\xfe\x01\x12\"\n\x1d\x46N_BETWEEN_INT64_UINT64_INT64\x10\xff\x01\x12\"\n\x1d\x46N_BETWEEN_INT64_INT64_UINT64\x10\x80\x02\x12\"\n\x1d\x46N_BETWEEN_UINT64_INT64_INT64\x10\x81\x02\x12#\n\x1e\x46N_BETWEEN_UINT64_UINT64_INT64\x10\x82\x02\x12#\n\x1e\x46N_BETWEEN_UINT64_INT64_UINT64\x10\x83\x02\x12\x0e\n\nFN_IS_NULL\x10\x65\x12\x0e\n\nFN_IS_TRUE\x10\x66\x12\x0f\n\x0b\x46N_IS_FALSE\x10g\x12\x16\n\x12\x46N_MULTIPLY_DOUBLE\x10)\x12\x15\n\x11\x46N_MULTIPLY_INT64\x10,\x12\x16\n\x12\x46N_MULTIPLY_UINT64\x10r\x12\x18\n\x13\x46N_MULTIPLY_NUMERIC\x10\xfb\x01\x12\x1b\n\x16\x46N_MULTIPLY_BIGNUMERIC\x10\x88\x02\x12\x1f\n\x1a\x46N_MULTIPLY_INTERVAL_INT64\x10\xab\x02\x12\x1f\n\x1a\x46N_MULTIPLY_INT64_INTERVAL\x10\xac\x02\x12\n\n\x06\x46N_NOT\x10-\x12\x10\n\x0c\x46N_NOT_EQUAL\x10m\x12\x1e\n\x19\x46N_NOT_EQUAL_INT64_UINT64\x10\xe8\x01\x12\x1e\n\x19\x46N_NOT_EQUAL_UINT64_INT64\x10\xe9\x01\x12\t\n\x05\x46N_OR\x10.\x12\x16\n\x12\x46N_SUBTRACT_DOUBLE\x10s\x12\x15\n\x11\x46N_SUBTRACT_INT64\x10\x30\x12\x16\n\x12\x46N_SUBTRACT_UINT64\x10u\x12\x18\n\x13\x46N_SUBTRACT_NUMERIC\x10\xf9\x01\x12\x1b\n\x16\x46N_SUBTRACT_BIGNUMERIC\x10\x86\x02\x12\x1b\n\x16\x46N_SUBTRACT_DATE_INT64\x10\x8c\x02\x12\x15\n\x10\x46N_SUBTRACT_DATE\x10\x94\x02\x12\x1a\n\x15\x46N_SUBTRACT_TIMESTAMP\x10\x95\x02\x12\x19\n\x14\x46N_SUBTRACT_DATETIME\x10\x96\x02\x12\x15\n\x10\x46N_SUBTRACT_TIME\x10\x97\x02\x12#\n\x1e\x46N_SUBTRACT_TIMESTAMP_INTERVAL\x10\x9e\x02\x12\x1e\n\x19\x46N_SUBTRACT_DATE_INTERVAL\x10\x9f\x02\x12\"\n\x1d\x46N_SUBTRACT_DATETIME_INTERVAL\x10\xa0\x02\x12\"\n\x1d\x46N_SUBTRACT_INTERVAL_INTERVAL\x10\xa2\x02\x12\x18\n\x14\x46N_UNARY_MINUS_INT32\x10S\x12\x18\n\x14\x46N_UNARY_MINUS_INT64\x10T\x12\x18\n\x14\x46N_UNARY_MINUS_FLOAT\x10W\x12\x19\n\x15\x46N_UNARY_MINUS_DOUBLE\x10X\x12\x1b\n\x16\x46N_UNARY_MINUS_NUMERIC\x10\xfc\x01\x12\x1e\n\x19\x46N_UNARY_MINUS_BIGNUMERIC\x10\x89\x02\x12\x1c\n\x17\x46N_UNARY_MINUS_INTERVAL\x10\x93\x02\x12\x10\n\x0b\x46N_DISTINCT\x10\x8d\x02\x12\x1d\n\x18\x46N_DISTINCT_INT64_UINT64\x10\x8e\x02\x12\x1d\n\x18\x46N_DISTINCT_UINT64_INT64\x10\x8f\x02\x12\x14\n\x0f\x46N_NOT_DISTINCT\x10\x90\x02\x12!\n\x1c\x46N_NOT_DISTINCT_INT64_UINT64\x10\x91\x02\x12!\n\x1c\x46N_NOT_DISTINCT_UINT64_INT64\x10\x92\x02\x12\x18\n\x14\x46N_BITWISE_NOT_INT32\x10x\x12\x18\n\x14\x46N_BITWISE_NOT_INT64\x10y\x12\x19\n\x15\x46N_BITWISE_NOT_UINT32\x10z\x12\x19\n\x15\x46N_BITWISE_NOT_UINT64\x10{\x12\x19\n\x14\x46N_BITWISE_NOT_BYTES\x10\xf1\x01\x12\x17\n\x13\x46N_BITWISE_OR_INT32\x10|\x12\x17\n\x13\x46N_BITWISE_OR_INT64\x10}\x12\x18\n\x14\x46N_BITWISE_OR_UINT32\x10~\x12\x18\n\x14\x46N_BITWISE_OR_UINT64\x10\x7f\x12\x18\n\x13\x46N_BITWISE_OR_BYTES\x10\xf2\x01\x12\x19\n\x14\x46N_BITWISE_XOR_INT32\x10\x80\x01\x12\x19\n\x14\x46N_BITWISE_XOR_INT64\x10\x81\x01\x12\x1a\n\x15\x46N_BITWISE_XOR_UINT32\x10\x82\x01\x12\x1a\n\x15\x46N_BITWISE_XOR_UINT64\x10\x83\x01\x12\x19\n\x14\x46N_BITWISE_XOR_BYTES\x10\xf3\x01\x12\x19\n\x14\x46N_BITWISE_AND_INT32\x10\x84\x01\x12\x19\n\x14\x46N_BITWISE_AND_INT64\x10\x85\x01\x12\x1a\n\x15\x46N_BITWISE_AND_UINT32\x10\x86\x01\x12\x1a\n\x15\x46N_BITWISE_AND_UINT64\x10\x87\x01\x12\x19\n\x14\x46N_BITWISE_AND_BYTES\x10\xf4\x01\x12 \n\x1b\x46N_BITWISE_LEFT_SHIFT_INT32\x10\x88\x01\x12 \n\x1b\x46N_BITWISE_LEFT_SHIFT_INT64\x10\x89\x01\x12!\n\x1c\x46N_BITWISE_LEFT_SHIFT_UINT32\x10\x8a\x01\x12!\n\x1c\x46N_BITWISE_LEFT_SHIFT_UINT64\x10\x8b\x01\x12 \n\x1b\x46N_BITWISE_LEFT_SHIFT_BYTES\x10\xf5\x01\x12!\n\x1c\x46N_BITWISE_RIGHT_SHIFT_INT32\x10\x8c\x01\x12!\n\x1c\x46N_BITWISE_RIGHT_SHIFT_INT64\x10\x8d\x01\x12\"\n\x1d\x46N_BITWISE_RIGHT_SHIFT_UINT32\x10\x8e\x01\x12\"\n\x1d\x46N_BITWISE_RIGHT_SHIFT_UINT64\x10\x8f\x01\x12!\n\x1c\x46N_BITWISE_RIGHT_SHIFT_BYTES\x10\xf6\x01\x12\x17\n\x12\x46N_BIT_COUNT_INT32\x10\x90\x01\x12\x17\n\x12\x46N_BIT_COUNT_INT64\x10\x91\x01\x12\x18\n\x13\x46N_BIT_COUNT_UINT64\x10\x92\x01\x12\x17\n\x12\x46N_BIT_COUNT_BYTES\x10\xf7\x01\x12\x0e\n\tFN_TYPEOF\x10\xa3\r\x12\r\n\x08\x46N_ERROR\x10\xfd\x01\x12\x11\n\rFN_COUNT_STAR\x10\x39\x12\x15\n\x10\x46N_CONCAT_STRING\x10\xe8\x07\x12\x14\n\x0f\x46N_CONCAT_BYTES\x10\xe9\x07\x12\x18\n\x13\x46N_CONCAT_OP_STRING\x10\xa7\x08\x12\x17\n\x12\x46N_CONCAT_OP_BYTES\x10\xa8\x08\x12\x15\n\x10\x46N_STRPOS_STRING\x10\xea\x07\x12\x14\n\x0f\x46N_STRPOS_BYTES\x10\xeb\x07\x12\x14\n\x0f\x46N_INSTR_STRING\x10\xae\x08\x12\x13\n\x0e\x46N_INSTR_BYTES\x10\xaf\x08\x12\x14\n\x0f\x46N_LOWER_STRING\x10\xee\x07\x12\x13\n\x0e\x46N_LOWER_BYTES\x10\xef\x07\x12\x14\n\x0f\x46N_UPPER_STRING\x10\xf0\x07\x12\x13\n\x0e\x46N_UPPER_BYTES\x10\xf1\x07\x12\x15\n\x10\x46N_LENGTH_STRING\x10\xf2\x07\x12\x14\n\x0f\x46N_LENGTH_BYTES\x10\xf3\x07\x12\x1a\n\x15\x46N_STARTS_WITH_STRING\x10\xf4\x07\x12\x19\n\x14\x46N_STARTS_WITH_BYTES\x10\xf5\x07\x12\x18\n\x13\x46N_ENDS_WITH_STRING\x10\xf6\x07\x12\x17\n\x12\x46N_ENDS_WITH_BYTES\x10\xf7\x07\x12\x15\n\x10\x46N_SUBSTR_STRING\x10\xf8\x07\x12\x14\n\x0f\x46N_SUBSTR_BYTES\x10\xf9\x07\x12\x13\n\x0e\x46N_TRIM_STRING\x10\xfa\x07\x12\x12\n\rFN_TRIM_BYTES\x10\xfb\x07\x12\x14\n\x0f\x46N_LTRIM_STRING\x10\xfc\x07\x12\x13\n\x0e\x46N_LTRIM_BYTES\x10\xfd\x07\x12\x14\n\x0f\x46N_RTRIM_STRING\x10\xfe\x07\x12\x13\n\x0e\x46N_RTRIM_BYTES\x10\xff\x07\x12\x16\n\x11\x46N_REPLACE_STRING\x10\x80\x08\x12\x15\n\x10\x46N_REPLACE_BYTES\x10\x81\x08\x12\x1b\n\x16\x46N_REGEXP_MATCH_STRING\x10\x82\x08\x12\x1a\n\x15\x46N_REGEXP_MATCH_BYTES\x10\x83\x08\x12\x1d\n\x18\x46N_REGEXP_EXTRACT_STRING\x10\x84\x08\x12\x1c\n\x17\x46N_REGEXP_EXTRACT_BYTES\x10\x85\x08\x12\x1d\n\x18\x46N_REGEXP_REPLACE_STRING\x10\x86\x08\x12\x1c\n\x17\x46N_REGEXP_REPLACE_BYTES\x10\x87\x08\x12!\n\x1c\x46N_REGEXP_EXTRACT_ALL_STRING\x10\x88\x08\x12 \n\x1b\x46N_REGEXP_EXTRACT_ALL_BYTES\x10\x89\x08\x12\x1a\n\x15\x46N_BYTE_LENGTH_STRING\x10\x8a\x08\x12\x19\n\x14\x46N_BYTE_LENGTH_BYTES\x10\x8b\x08\x12\x1a\n\x15\x46N_CHAR_LENGTH_STRING\x10\x8c\x08\x12\x15\n\x10\x46N_FORMAT_STRING\x10\x8d\x08\x12\x14\n\x0f\x46N_SPLIT_STRING\x10\x8e\x08\x12\x13\n\x0e\x46N_SPLIT_BYTES\x10\x8f\x08\x12\x1e\n\x19\x46N_REGEXP_CONTAINS_STRING\x10\x90\x08\x12\x1d\n\x18\x46N_REGEXP_CONTAINS_BYTES\x10\x91\x08\x12$\n\x1f\x46N_SAFE_CONVERT_BYTES_TO_STRING\x10\x92\x08\x12\x18\n\x13\x46N_NORMALIZE_STRING\x10\x93\x08\x12%\n FN_NORMALIZE_AND_CASEFOLD_STRING\x10\x94\x08\x12\x11\n\x0c\x46N_TO_BASE64\x10\x95\x08\x12\x13\n\x0e\x46N_FROM_BASE64\x10\x96\x08\x12\x0e\n\tFN_TO_HEX\x10\xa3\x08\x12\x10\n\x0b\x46N_FROM_HEX\x10\xa4\x08\x12\x11\n\x0c\x46N_TO_BASE32\x10\xa5\x08\x12\x13\n\x0e\x46N_FROM_BASE32\x10\xa6\x08\x12\x1d\n\x18\x46N_TO_CODE_POINTS_STRING\x10\x97\x08\x12\x1c\n\x17\x46N_TO_CODE_POINTS_BYTES\x10\x98\x08\x12\x1d\n\x18\x46N_CODE_POINTS_TO_STRING\x10\x99\x08\x12\x1c\n\x17\x46N_CODE_POINTS_TO_BYTES\x10\x9a\x08\x12\x12\n\rFN_LPAD_BYTES\x10\x9b\x08\x12\x13\n\x0e\x46N_LPAD_STRING\x10\x9c\x08\x12\x12\n\rFN_RPAD_BYTES\x10\x9d\x08\x12\x13\n\x0e\x46N_RPAD_STRING\x10\x9e\x08\x12\x13\n\x0e\x46N_LEFT_STRING\x10\xa9\x08\x12\x12\n\rFN_LEFT_BYTES\x10\xaa\x08\x12\x14\n\x0f\x46N_RIGHT_STRING\x10\xab\x08\x12\x13\n\x0e\x46N_RIGHT_BYTES\x10\xac\x08\x12\x14\n\x0f\x46N_REPEAT_BYTES\x10\x9f\x08\x12\x15\n\x10\x46N_REPEAT_STRING\x10\xa0\x08\x12\x16\n\x11\x46N_REVERSE_STRING\x10\xa1\x08\x12\x15\n\x10\x46N_REVERSE_BYTES\x10\xa2\x08\x12\x16\n\x11\x46N_SOUNDEX_STRING\x10\xad\x08\x12\x14\n\x0f\x46N_ASCII_STRING\x10\xb0\x08\x12\x13\n\x0e\x46N_ASCII_BYTES\x10\xb1\x08\x12\x18\n\x13\x46N_TRANSLATE_STRING\x10\xb2\x08\x12\x17\n\x12\x46N_TRANSLATE_BYTES\x10\xb3\x08\x12\x16\n\x11\x46N_INITCAP_STRING\x10\xb4\x08\x12\x16\n\x11\x46N_UNICODE_STRING\x10\xb5\x08\x12\x12\n\rFN_CHR_STRING\x10\xb6\x08\x12\x0f\n\nFN_COLLATE\x10\xba\x08\x12\x1b\n\x16\x46N_REGEXP_INSTR_STRING\x10\xb7\x08\x12\x1a\n\x15\x46N_REGEXP_INSTR_BYTES\x10\xb8\x08\x12\x14\n\x0f\x46N_SPLIT_SUBSTR\x10\xbb\x08\x12$\n\x1f\x46N_REGEXP_EXTRACT_GROUPS_STRING\x10\xbc\x08\x12#\n\x1e\x46N_REGEXP_EXTRACT_GROUPS_BYTES\x10\xbd\x08\x12\n\n\x05\x46N_IF\x10\xcc\x08\x12\x10\n\x0b\x46N_COALESCE\x10\xcd\x08\x12\x0e\n\tFN_IFNULL\x10\xce\x08\x12\x0e\n\tFN_NULLIF\x10\xcf\x08\x12\x0f\n\nFN_IFERROR\x10\xd0\x08\x12\x13\n\x0e\x46N_NULLIFERROR\x10\xd1\x08\x12\x0f\n\nFN_ISERROR\x10\xd2\x08\x12\x19\n\x14\x46N_WITH_SIDE_EFFECTS\x10\xd3\x08\x12\x14\n\x0f\x46N_CURRENT_DATE\x10\xb0\t\x12\x18\n\x13\x46N_CURRENT_DATETIME\x10\x8c\x0e\x12\x14\n\x0f\x46N_CURRENT_TIME\x10\x8d\x0e\x12\x19\n\x14\x46N_CURRENT_TIMESTAMP\x10\xec\t\x12\x15\n\x10\x46N_DATE_ADD_DATE\x10\xb5\t\x12\x14\n\x0f\x46N_DATETIME_ADD\x10\x94\x0e\x12\x10\n\x0b\x46N_TIME_ADD\x10\x95\x0e\x12\x15\n\x10\x46N_TIMESTAMP_ADD\x10\xed\t\x12\x16\n\x11\x46N_DATE_DIFF_DATE\x10\xba\t\x12\x15\n\x10\x46N_DATETIME_DIFF\x10\x98\x0e\x12\x11\n\x0c\x46N_TIME_DIFF\x10\x99\x0e\x12\x16\n\x11\x46N_TIMESTAMP_DIFF\x10\xee\t\x12\x15\n\x10\x46N_DATE_SUB_DATE\x10\xbf\t\x12\x14\n\x0f\x46N_DATETIME_SUB\x10\x96\x0e\x12\x10\n\x0b\x46N_TIME_SUB\x10\x97\x0e\x12\x15\n\x10\x46N_TIMESTAMP_SUB\x10\xef\t\x12\x17\n\x12\x46N_DATE_TRUNC_DATE\x10\xc4\t\x12\x16\n\x11\x46N_DATETIME_TRUNC\x10\x9a\x0e\x12\x12\n\rFN_TIME_TRUNC\x10\x9b\x0e\x12\x17\n\x12\x46N_TIMESTAMP_TRUNC\x10\xf0\t\x12\x17\n\x12\x46N_ADD_MONTHS_DATE\x10\xce\x0e\x12\x1b\n\x16\x46N_ADD_MONTHS_DATETIME\x10\xcf\x0e\x12\x15\n\x10\x46N_NEXT_DAY_DATE\x10\xd0\x0e\x12\x19\n\x14\x46N_NEXT_DAY_DATETIME\x10\xd1\x0e\x12\x1b\n\x16\x46N_DATE_FROM_UNIX_DATE\x10\xc9\t\x12$\n\x1f\x46N_TIMESTAMP_FROM_INT64_SECONDS\x10\x89\n\x12#\n\x1e\x46N_TIMESTAMP_FROM_INT64_MILLIS\x10\x8a\n\x12#\n\x1e\x46N_TIMESTAMP_FROM_INT64_MICROS\x10\x8b\n\x12)\n$FN_TIMESTAMP_FROM_UNIX_SECONDS_INT64\x10\xa3\x0e\x12*\n%FN_TIMESTAMP_FROM_UNIX_SECONDS_UINT64\x10\xc8\x0e\x12-\n(FN_TIMESTAMP_FROM_UNIX_SECONDS_TIMESTAMP\x10\xa4\x0e\x12(\n#FN_TIMESTAMP_FROM_UNIX_MILLIS_INT64\x10\xa5\x0e\x12)\n$FN_TIMESTAMP_FROM_UNIX_MILLIS_UINT64\x10\xc9\x0e\x12,\n\'FN_TIMESTAMP_FROM_UNIX_MILLIS_TIMESTAMP\x10\xa6\x0e\x12(\n#FN_TIMESTAMP_FROM_UNIX_MICROS_INT64\x10\xa7\x0e\x12)\n$FN_TIMESTAMP_FROM_UNIX_MICROS_UINT64\x10\xca\x0e\x12,\n\'FN_TIMESTAMP_FROM_UNIX_MICROS_TIMESTAMP\x10\xa8\x0e\x12\x11\n\x0c\x46N_UNIX_DATE\x10\xce\t\x12#\n\x1e\x46N_UNIX_SECONDS_FROM_TIMESTAMP\x10\xf4\t\x12\"\n\x1d\x46N_UNIX_MILLIS_FROM_TIMESTAMP\x10\xf5\t\x12\"\n\x1d\x46N_UNIX_MICROS_FROM_TIMESTAMP\x10\xf6\t\x12\x1b\n\x16\x46N_DATE_FROM_TIMESTAMP\x10\xf7\t\x12\x1a\n\x15\x46N_DATE_FROM_DATETIME\x10\xa2\x0e\x12\x16\n\x11\x46N_DATE_FROM_DATE\x10\xa9\x0e\x12\x18\n\x13\x46N_DATE_FROM_STRING\x10\xad\x0e\x12 \n\x1b\x46N_DATE_FROM_YEAR_MONTH_DAY\x10\x91\n\x12\x1d\n\x18\x46N_TIMESTAMP_FROM_STRING\x10\xf8\t\x12\x1b\n\x16\x46N_TIMESTAMP_FROM_DATE\x10\xf9\t\x12\x1f\n\x1a\x46N_TIMESTAMP_FROM_DATETIME\x10\x89\x0e\x12 \n\x1b\x46N_TIMESTAMP_FROM_TIMESTAMP\x10\xaa\x0e\x12$\n\x1f\x46N_TIME_FROM_HOUR_MINUTE_SECOND\x10\x92\n\x12\x1b\n\x16\x46N_TIME_FROM_TIMESTAMP\x10\x8a\x0e\x12\x1a\n\x15\x46N_TIME_FROM_DATETIME\x10\xa1\x0e\x12\x16\n\x11\x46N_TIME_FROM_TIME\x10\xac\x0e\x12\x18\n\x13\x46N_TIME_FROM_STRING\x10\xae\x0e\x12#\n\x1e\x46N_DATETIME_FROM_DATE_AND_TIME\x10\x93\n\x12\x37\n2FN_DATETIME_FROM_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND\x10\x88\x0e\x12\x1f\n\x1a\x46N_DATETIME_FROM_TIMESTAMP\x10\x8b\x0e\x12\x1a\n\x15\x46N_DATETIME_FROM_DATE\x10\xa0\x0e\x12\x1e\n\x19\x46N_DATETIME_FROM_DATETIME\x10\xab\x0e\x12\x1c\n\x17\x46N_DATETIME_FROM_STRING\x10\xaf\x0e\x12\x18\n\x13\x46N_STRING_FROM_DATE\x10\xb0\x0e\x12\x1d\n\x18\x46N_STRING_FROM_TIMESTAMP\x10\xfa\t\x12\x1c\n\x17\x46N_STRING_FROM_DATETIME\x10\xb1\x0e\x12\x18\n\x13\x46N_STRING_FROM_TIME\x10\xb2\x0e\x12\x19\n\x14\x46N_EXTRACT_FROM_DATE\x10\xe3\t\x12\x1d\n\x18\x46N_EXTRACT_FROM_DATETIME\x10\x8e\x0e\x12\x19\n\x14\x46N_EXTRACT_FROM_TIME\x10\x8f\x0e\x12\x1e\n\x19\x46N_EXTRACT_FROM_TIMESTAMP\x10\xfb\t\x12\x1d\n\x18\x46N_EXTRACT_FROM_INTERVAL\x10\xc1\x0e\x12\"\n\x1d\x46N_EXTRACT_DATE_FROM_DATETIME\x10\x90\x0e\x12#\n\x1e\x46N_EXTRACT_DATE_FROM_TIMESTAMP\x10\xfc\t\x12\"\n\x1d\x46N_EXTRACT_TIME_FROM_DATETIME\x10\x91\x0e\x12#\n\x1e\x46N_EXTRACT_TIME_FROM_TIMESTAMP\x10\x92\x0e\x12\'\n\"FN_EXTRACT_DATETIME_FROM_TIMESTAMP\x10\x93\x0e\x12\x13\n\x0e\x46N_FORMAT_DATE\x10\x8d\n\x12\x17\n\x12\x46N_FORMAT_DATETIME\x10\x9c\x0e\x12\x13\n\x0e\x46N_FORMAT_TIME\x10\x9d\x0e\x12\x18\n\x13\x46N_FORMAT_TIMESTAMP\x10\x8e\n\x12\x12\n\rFN_PARSE_DATE\x10\x8f\n\x12\x16\n\x11\x46N_PARSE_DATETIME\x10\x9e\x0e\x12\x12\n\rFN_PARSE_TIME\x10\x9f\x0e\x12\x17\n\x12\x46N_PARSE_TIMESTAMP\x10\x90\n\x12&\n!FN_PARSE_TIMESTAMP_WITH_PRECISION\x10\xcc\x0e\x12\x33\n.FN_PARSE_TIMESTAMP_WITH_PRECISION_AND_TIMEZONE\x10\xcd\x0e\x12\x15\n\x10\x46N_LAST_DAY_DATE\x10\xb3\x0e\x12\x19\n\x14\x46N_LAST_DAY_DATETIME\x10\xb4\x0e\x12\x1c\n\x17\x46N_INTERVAL_CONSTRUCTOR\x10\xbf\x0e\x12\x15\n\x10\x46N_MAKE_INTERVAL\x10\xc0\x0e\x12\x15\n\x10\x46N_JUSTIFY_HOURS\x10\xc2\x0e\x12\x14\n\x0f\x46N_JUSTIFY_DAYS\x10\xc3\x0e\x12\x18\n\x13\x46N_JUSTIFY_INTERVAL\x10\xc4\x0e\x12\x1b\n\x16\x46N_TO_SECONDS_INTERVAL\x10\xcb\x0e\x12\x18\n\x13\x46N_TIMESTAMP_BUCKET\x10\xc5\x0e\x12\x17\n\x12\x46N_DATETIME_BUCKET\x10\xc6\x0e\x12\x13\n\x0e\x46N_DATE_BUCKET\x10\xc7\x0e\x12\x11\n\x0c\x46N_ABS_INT32\x10\x94\n\x12\x11\n\x0c\x46N_ABS_INT64\x10\x95\n\x12\x12\n\rFN_ABS_UINT32\x10\xc2\n\x12\x12\n\rFN_ABS_UINT64\x10\xc3\n\x12\x11\n\x0c\x46N_ABS_FLOAT\x10\x96\n\x12\x12\n\rFN_ABS_DOUBLE\x10\x97\n\x12\x13\n\x0e\x46N_ABS_NUMERIC\x10\xcf\n\x12\x16\n\x11\x46N_ABS_BIGNUMERIC\x10\xf3\n\x12\x12\n\rFN_SIGN_INT32\x10\xbd\n\x12\x12\n\rFN_SIGN_INT64\x10\xbe\n\x12\x13\n\x0e\x46N_SIGN_UINT32\x10\xcc\n\x12\x13\n\x0e\x46N_SIGN_UINT64\x10\xcd\n\x12\x12\n\rFN_SIGN_FLOAT\x10\xbf\n\x12\x13\n\x0e\x46N_SIGN_DOUBLE\x10\xc0\n\x12\x14\n\x0f\x46N_SIGN_NUMERIC\x10\xd0\n\x12\x17\n\x12\x46N_SIGN_BIGNUMERIC\x10\xf4\n\x12\x14\n\x0f\x46N_ROUND_DOUBLE\x10\x99\n\x12\x13\n\x0e\x46N_ROUND_FLOAT\x10\x9a\n\x12\x15\n\x10\x46N_ROUND_NUMERIC\x10\xd3\n\x12\x18\n\x13\x46N_ROUND_BIGNUMERIC\x10\xf5\n\x12 \n\x1b\x46N_ROUND_WITH_DIGITS_DOUBLE\x10\x9b\n\x12\x1f\n\x1a\x46N_ROUND_WITH_DIGITS_FLOAT\x10\x9c\n\x12!\n\x1c\x46N_ROUND_WITH_DIGITS_NUMERIC\x10\xd4\n\x12$\n\x1f\x46N_ROUND_WITH_DIGITS_BIGNUMERIC\x10\xf6\n\x12(\n#FN_ROUND_WITH_ROUNDING_MODE_NUMERIC\x10\x99\x0f\x12+\n&FN_ROUND_WITH_ROUNDING_MODE_BIGNUMERIC\x10\x9a\x0f\x12\x14\n\x0f\x46N_TRUNC_DOUBLE\x10\x9d\n\x12\x13\n\x0e\x46N_TRUNC_FLOAT\x10\x9e\n\x12\x15\n\x10\x46N_TRUNC_NUMERIC\x10\xd5\n\x12\x18\n\x13\x46N_TRUNC_BIGNUMERIC\x10\xf7\n\x12 \n\x1b\x46N_TRUNC_WITH_DIGITS_DOUBLE\x10\x9f\n\x12\x1f\n\x1a\x46N_TRUNC_WITH_DIGITS_FLOAT\x10\xa0\n\x12!\n\x1c\x46N_TRUNC_WITH_DIGITS_NUMERIC\x10\xd6\n\x12$\n\x1f\x46N_TRUNC_WITH_DIGITS_BIGNUMERIC\x10\xfc\x11\x12\x13\n\x0e\x46N_CEIL_DOUBLE\x10\xa1\n\x12\x12\n\rFN_CEIL_FLOAT\x10\xa2\n\x12\x14\n\x0f\x46N_CEIL_NUMERIC\x10\xd8\n\x12\x17\n\x12\x46N_CEIL_BIGNUMERIC\x10\xf1\n\x12\x14\n\x0f\x46N_FLOOR_DOUBLE\x10\xa3\n\x12\x13\n\x0e\x46N_FLOOR_FLOAT\x10\xa4\n\x12\x15\n\x10\x46N_FLOOR_NUMERIC\x10\xd9\n\x12\x18\n\x13\x46N_FLOOR_BIGNUMERIC\x10\xf2\n\x12\x11\n\x0c\x46N_MOD_INT64\x10\xc5\n\x12\x12\n\rFN_MOD_UINT64\x10\xc7\n\x12\x13\n\x0e\x46N_MOD_NUMERIC\x10\xd7\n\x12\x16\n\x11\x46N_MOD_BIGNUMERIC\x10\xfd\x11\x12\x11\n\x0c\x46N_DIV_INT64\x10\xc9\n\x12\x12\n\rFN_DIV_UINT64\x10\xcb\n\x12\x13\n\x0e\x46N_DIV_NUMERIC\x10\xd2\n\x12\x16\n\x11\x46N_DIV_BIGNUMERIC\x10\xfe\x11\x12\x0e\n\tFN_IS_INF\x10\xa5\n\x12\x0e\n\tFN_IS_NAN\x10\xa6\n\x12\x1a\n\x15\x46N_IEEE_DIVIDE_DOUBLE\x10\xa7\n\x12\x19\n\x14\x46N_IEEE_DIVIDE_FLOAT\x10\xa8\n\x12\x1a\n\x15\x46N_SAFE_DIVIDE_DOUBLE\x10\xce\n\x12\x1b\n\x16\x46N_SAFE_DIVIDE_NUMERIC\x10\xd1\n\x12\x1e\n\x19\x46N_SAFE_DIVIDE_BIGNUMERIC\x10\xec\n\x12\x16\n\x11\x46N_SAFE_ADD_INT64\x10\xdb\n\x12\x17\n\x12\x46N_SAFE_ADD_UINT64\x10\xdc\n\x12\x17\n\x12\x46N_SAFE_ADD_DOUBLE\x10\xdd\n\x12\x18\n\x13\x46N_SAFE_ADD_NUMERIC\x10\xde\n\x12\x1b\n\x16\x46N_SAFE_ADD_BIGNUMERIC\x10\xed\n\x12\x1b\n\x16\x46N_SAFE_SUBTRACT_INT64\x10\xdf\n\x12\x1c\n\x17\x46N_SAFE_SUBTRACT_UINT64\x10\xe0\n\x12\x1c\n\x17\x46N_SAFE_SUBTRACT_DOUBLE\x10\xe1\n\x12\x1d\n\x18\x46N_SAFE_SUBTRACT_NUMERIC\x10\xe2\n\x12 \n\x1b\x46N_SAFE_SUBTRACT_BIGNUMERIC\x10\xee\n\x12\x1b\n\x16\x46N_SAFE_MULTIPLY_INT64\x10\xe3\n\x12\x1c\n\x17\x46N_SAFE_MULTIPLY_UINT64\x10\xe4\n\x12\x1c\n\x17\x46N_SAFE_MULTIPLY_DOUBLE\x10\xe5\n\x12\x1d\n\x18\x46N_SAFE_MULTIPLY_NUMERIC\x10\xe6\n\x12 \n\x1b\x46N_SAFE_MULTIPLY_BIGNUMERIC\x10\xef\n\x12\x1e\n\x19\x46N_SAFE_UNARY_MINUS_INT32\x10\xe7\n\x12\x1e\n\x19\x46N_SAFE_UNARY_MINUS_INT64\x10\xe8\n\x12\x1e\n\x19\x46N_SAFE_UNARY_MINUS_FLOAT\x10\xe9\n\x12\x1f\n\x1a\x46N_SAFE_UNARY_MINUS_DOUBLE\x10\xea\n\x12 \n\x1b\x46N_SAFE_UNARY_MINUS_NUMERIC\x10\xeb\n\x12#\n\x1e\x46N_SAFE_UNARY_MINUS_BIGNUMERIC\x10\xf0\n\x12\x10\n\x0b\x46N_GREATEST\x10\xa9\n\x12\r\n\x08\x46N_LEAST\x10\xaa\n\x12\x13\n\x0e\x46N_SQRT_DOUBLE\x10\xab\n\x12\x14\n\x0f\x46N_SQRT_NUMERIC\x10\x84\x12\x12\x17\n\x12\x46N_SQRT_BIGNUMERIC\x10\x85\x12\x12\x13\n\x0e\x46N_CBRT_DOUBLE\x10\x92\x12\x12\x14\n\x0f\x46N_CBRT_NUMERIC\x10\x93\x12\x12\x17\n\x12\x46N_CBRT_BIGNUMERIC\x10\x94\x12\x12\x12\n\rFN_POW_DOUBLE\x10\xac\n\x12\x13\n\x0e\x46N_POW_NUMERIC\x10\xda\n\x12\x16\n\x11\x46N_POW_BIGNUMERIC\x10\xff\x11\x12\x12\n\rFN_EXP_DOUBLE\x10\xad\n\x12\x13\n\x0e\x46N_EXP_NUMERIC\x10\x80\x12\x12\x16\n\x11\x46N_EXP_BIGNUMERIC\x10\x81\x12\x12 \n\x1b\x46N_NATURAL_LOGARITHM_DOUBLE\x10\xae\n\x12!\n\x1c\x46N_NATURAL_LOGARITHM_NUMERIC\x10\x82\x12\x12$\n\x1f\x46N_NATURAL_LOGARITHM_BIGNUMERIC\x10\x83\x12\x12 \n\x1b\x46N_DECIMAL_LOGARITHM_DOUBLE\x10\xc1\n\x12!\n\x1c\x46N_DECIMAL_LOGARITHM_NUMERIC\x10\x86\x12\x12$\n\x1f\x46N_DECIMAL_LOGARITHM_BIGNUMERIC\x10\x87\x12\x12\x18\n\x13\x46N_LOGARITHM_DOUBLE\x10\xaf\n\x12\x19\n\x14\x46N_LOGARITHM_NUMERIC\x10\x88\x12\x12\x1c\n\x17\x46N_LOGARITHM_BIGNUMERIC\x10\x89\x12\x12\x15\n\x10\x46N_PARSE_NUMERIC\x10\x8a\x12\x12\x18\n\x13\x46N_PARSE_BIGNUMERIC\x10\x8b\x12\x12\x11\n\x0c\x46N_PI_DOUBLE\x10\x95\x12\x12\x12\n\rFN_PI_NUMERIC\x10\x96\x12\x12\x15\n\x10\x46N_PI_BIGNUMERIC\x10\x97\x12\x12\x18\n\x13\x46N_NULLIFZERO_INT32\x10\x99\x12\x12\x19\n\x14\x46N_NULLIFZERO_UINT32\x10\x9a\x12\x12\x18\n\x13\x46N_NULLIFZERO_INT64\x10\x9b\x12\x12\x19\n\x14\x46N_NULLIFZERO_UINT64\x10\x9c\x12\x12\x18\n\x13\x46N_NULLIFZERO_FLOAT\x10\x9d\x12\x12\x19\n\x14\x46N_NULLIFZERO_DOUBLE\x10\x9e\x12\x12\x1a\n\x15\x46N_NULLIFZERO_NUMERIC\x10\x9f\x12\x12\x1d\n\x18\x46N_NULLIFZERO_BIGNUMERIC\x10\xa0\x12\x12\x18\n\x13\x46N_ZEROIFNULL_INT32\x10\xa1\x12\x12\x19\n\x14\x46N_ZEROIFNULL_UINT32\x10\xa2\x12\x12\x18\n\x13\x46N_ZEROIFNULL_INT64\x10\xa3\x12\x12\x19\n\x14\x46N_ZEROIFNULL_UINT64\x10\xa4\x12\x12\x18\n\x13\x46N_ZEROIFNULL_FLOAT\x10\xa5\x12\x12\x19\n\x14\x46N_ZEROIFNULL_DOUBLE\x10\xa6\x12\x12\x1a\n\x15\x46N_ZEROIFNULL_NUMERIC\x10\xa7\x12\x12\x1d\n\x18\x46N_ZEROIFNULL_BIGNUMERIC\x10\xa8\x12\x12\x12\n\rFN_COS_DOUBLE\x10\xb0\n\x12\x13\n\x0e\x46N_COSH_DOUBLE\x10\xb1\n\x12\x13\n\x0e\x46N_ACOS_DOUBLE\x10\xb2\n\x12\x14\n\x0f\x46N_ACOSH_DOUBLE\x10\xb3\n\x12\x12\n\rFN_SIN_DOUBLE\x10\xb4\n\x12\x13\n\x0e\x46N_SINH_DOUBLE\x10\xb5\n\x12\x13\n\x0e\x46N_ASIN_DOUBLE\x10\xb6\n\x12\x14\n\x0f\x46N_ASINH_DOUBLE\x10\xb7\n\x12\x12\n\rFN_TAN_DOUBLE\x10\xb8\n\x12\x13\n\x0e\x46N_TANH_DOUBLE\x10\xb9\n\x12\x13\n\x0e\x46N_ATAN_DOUBLE\x10\xba\n\x12\x14\n\x0f\x46N_ATANH_DOUBLE\x10\xbb\n\x12\x14\n\x0f\x46N_ATAN2_DOUBLE\x10\xbc\n\x12\x12\n\rFN_CSC_DOUBLE\x10\x8c\x12\x12\x12\n\rFN_SEC_DOUBLE\x10\x8d\x12\x12\x12\n\rFN_COT_DOUBLE\x10\x8e\x12\x12\x13\n\x0e\x46N_CSCH_DOUBLE\x10\x8f\x12\x12\x13\n\x0e\x46N_SECH_DOUBLE\x10\x90\x12\x12\x13\n\x0e\x46N_COTH_DOUBLE\x10\x91\x12\x12\x16\n\x11\x46N_RADIANS_DOUBLE\x10\xd7\x12\x12\x17\n\x12\x46N_RADIANS_NUMERIC\x10\xd8\x12\x12\x1a\n\x15\x46N_RADIANS_BIGNUMERIC\x10\xd9\x12\x12\x16\n\x11\x46N_DEGREES_DOUBLE\x10\xd4\x12\x12\x17\n\x12\x46N_DEGREES_NUMERIC\x10\xd5\x12\x12\x1a\n\x15\x46N_DEGREES_BIGNUMERIC\x10\xd6\x12\x12\x11\n\x0c\x46N_ANY_VALUE\x10\xf8\n\x12\x11\n\x0c\x46N_ARRAY_AGG\x10\xf9\n\x12\x18\n\x13\x46N_ARRAY_CONCAT_AGG\x10\xa2\x0b\x12\x11\n\x0c\x46N_AVG_INT64\x10\xfa\n\x12\x12\n\rFN_AVG_UINT64\x10\xfb\n\x12\x12\n\rFN_AVG_DOUBLE\x10\xfc\n\x12\x13\n\x0e\x46N_AVG_NUMERIC\x10\xbc\x0b\x12\x16\n\x11\x46N_AVG_BIGNUMERIC\x10\xc7\x0b\x12\x14\n\x0f\x46N_AVG_INTERVAL\x10\xd2\x0b\x12\r\n\x08\x46N_COUNT\x10\xfd\n\x12\x10\n\x0b\x46N_GROUPING\x10\x9b\x0f\x12\x0b\n\x06\x46N_MAX\x10\xfe\n\x12\x0b\n\x06\x46N_MIN\x10\xff\n\x12\x19\n\x14\x46N_STRING_AGG_STRING\x10\x80\x0b\x12\x1f\n\x1a\x46N_STRING_AGG_DELIM_STRING\x10\x81\x0b\x12\x18\n\x13\x46N_STRING_AGG_BYTES\x10\x85\x0b\x12\x1e\n\x19\x46N_STRING_AGG_DELIM_BYTES\x10\x86\x0b\x12\x11\n\x0c\x46N_SUM_INT64\x10\x82\x0b\x12\x12\n\rFN_SUM_UINT64\x10\x83\x0b\x12\x12\n\rFN_SUM_DOUBLE\x10\x84\x0b\x12\x13\n\x0e\x46N_SUM_NUMERIC\x10\xbb\x0b\x12\x16\n\x11\x46N_SUM_BIGNUMERIC\x10\xc6\x0b\x12\x14\n\x0f\x46N_SUM_INTERVAL\x10\xd1\x0b\x12\x15\n\x10\x46N_BIT_AND_INT32\x10\x87\x0b\x12\x15\n\x10\x46N_BIT_AND_INT64\x10\x88\x0b\x12\x16\n\x11\x46N_BIT_AND_UINT32\x10\x89\x0b\x12\x16\n\x11\x46N_BIT_AND_UINT64\x10\x8a\x0b\x12\x15\n\x10\x46N_BIT_AND_BYTES\x10\xdc\x15\x12\x14\n\x0f\x46N_BIT_OR_INT32\x10\x8b\x0b\x12\x14\n\x0f\x46N_BIT_OR_INT64\x10\x8c\x0b\x12\x15\n\x10\x46N_BIT_OR_UINT32\x10\x8d\x0b\x12\x15\n\x10\x46N_BIT_OR_UINT64\x10\x8e\x0b\x12\x14\n\x0f\x46N_BIT_OR_BYTES\x10\xdd\x15\x12\x15\n\x10\x46N_BIT_XOR_INT32\x10\x8f\x0b\x12\x15\n\x10\x46N_BIT_XOR_INT64\x10\x90\x0b\x12\x16\n\x11\x46N_BIT_XOR_UINT32\x10\x91\x0b\x12\x16\n\x11\x46N_BIT_XOR_UINT64\x10\x92\x0b\x12\x15\n\x10\x46N_BIT_XOR_BYTES\x10\xde\x15\x12\x13\n\x0e\x46N_LOGICAL_AND\x10\x93\x0b\x12\x12\n\rFN_LOGICAL_OR\x10\x94\x0b\x12\x1d\n\x18\x46N_APPROX_COUNT_DISTINCT\x10\x95\x0b\x12\x18\n\x13\x46N_APPROX_QUANTILES\x10\x96\x0b\x12\x18\n\x13\x46N_APPROX_TOP_COUNT\x10\x97\x0b\x12\x1c\n\x17\x46N_APPROX_TOP_SUM_INT64\x10\x98\x0b\x12\x1d\n\x18\x46N_APPROX_TOP_SUM_UINT64\x10\x99\x0b\x12\x1d\n\x18\x46N_APPROX_TOP_SUM_DOUBLE\x10\x9a\x0b\x12\x1e\n\x19\x46N_APPROX_TOP_SUM_NUMERIC\x10\xbd\x0b\x12!\n\x1c\x46N_APPROX_TOP_SUM_BIGNUMERIC\x10\xc8\x0b\x12\x17\n\x12\x46N_HLL_COUNT_MERGE\x10\xa4\x0b\x12\x19\n\x14\x46N_HLL_COUNT_EXTRACT\x10\xa5\x0b\x12\x1c\n\x17\x46N_HLL_COUNT_INIT_INT64\x10\xa6\x0b\x12\x1d\n\x18\x46N_HLL_COUNT_INIT_UINT64\x10\xa7\x0b\x12\x1e\n\x19\x46N_HLL_COUNT_INIT_NUMERIC\x10\xbe\x0b\x12!\n\x1c\x46N_HLL_COUNT_INIT_BIGNUMERIC\x10\xc9\x0b\x12\x1d\n\x18\x46N_HLL_COUNT_INIT_STRING\x10\xa8\x0b\x12\x1c\n\x17\x46N_HLL_COUNT_INIT_BYTES\x10\xa9\x0b\x12\x1f\n\x1a\x46N_HLL_COUNT_MERGE_PARTIAL\x10\xaa\x0b\x12\x17\n\x12\x46N_D3A_COUNT_MERGE\x10\xd3\x0b\x12\x19\n\x14\x46N_D3A_COUNT_EXTRACT\x10\xd4\x0b\x12\x1c\n\x17\x46N_D3A_COUNT_INIT_INT64\x10\xd5\x0b\x12\x1d\n\x18\x46N_D3A_COUNT_INIT_UINT64\x10\xd6\x0b\x12\x1e\n\x19\x46N_D3A_COUNT_INIT_NUMERIC\x10\xd7\x0b\x12!\n\x1c\x46N_D3A_COUNT_INIT_BIGNUMERIC\x10\xd8\x0b\x12\x1d\n\x18\x46N_D3A_COUNT_INIT_STRING\x10\xd9\x0b\x12\x1c\n\x17\x46N_D3A_COUNT_INIT_BYTES\x10\xda\x0b\x12\x1f\n\x1a\x46N_D3A_COUNT_MERGE_PARTIAL\x10\xdb\x0b\x12\x18\n\x13\x46N_D3A_COUNT_TO_HLL\x10\x8c\x15\x12\x0c\n\x07\x46N_CORR\x10\x9b\x0b\x12\x14\n\x0f\x46N_CORR_NUMERIC\x10\xbf\x0b\x12\x17\n\x12\x46N_CORR_BIGNUMERIC\x10\xd0\x0b\x12\x11\n\x0c\x46N_COVAR_POP\x10\x9c\x0b\x12\x19\n\x14\x46N_COVAR_POP_NUMERIC\x10\xc0\x0b\x12\x1c\n\x17\x46N_COVAR_POP_BIGNUMERIC\x10\xce\x0b\x12\x12\n\rFN_COVAR_SAMP\x10\x9d\x0b\x12\x1a\n\x15\x46N_COVAR_SAMP_NUMERIC\x10\xc1\x0b\x12\x1d\n\x18\x46N_COVAR_SAMP_BIGNUMERIC\x10\xcf\x0b\x12\x12\n\rFN_STDDEV_POP\x10\x9e\x0b\x12\x1a\n\x15\x46N_STDDEV_POP_NUMERIC\x10\xc2\x0b\x12\x1d\n\x18\x46N_STDDEV_POP_BIGNUMERIC\x10\xca\x0b\x12\x13\n\x0e\x46N_STDDEV_SAMP\x10\x9f\x0b\x12\x1b\n\x16\x46N_STDDEV_SAMP_NUMERIC\x10\xc3\x0b\x12\x1e\n\x19\x46N_STDDEV_SAMP_BIGNUMERIC\x10\xcb\x0b\x12\x0f\n\nFN_VAR_POP\x10\xa0\x0b\x12\x17\n\x12\x46N_VAR_POP_NUMERIC\x10\xc4\x0b\x12\x1a\n\x15\x46N_VAR_POP_BIGNUMERIC\x10\xcc\x0b\x12\x10\n\x0b\x46N_VAR_SAMP\x10\xa1\x0b\x12\x18\n\x13\x46N_VAR_SAMP_NUMERIC\x10\xc5\x0b\x12\x1b\n\x16\x46N_VAR_SAMP_BIGNUMERIC\x10\xcd\x0b\x12\x1d\n\x18\x46N_ELEMENTWISE_SUM_INT32\x10\xba\x15\x12\x1d\n\x18\x46N_ELEMENTWISE_SUM_INT64\x10\xbb\x15\x12\x1e\n\x19\x46N_ELEMENTWISE_SUM_UINT32\x10\xbc\x15\x12\x1e\n\x19\x46N_ELEMENTWISE_SUM_UINT64\x10\xbd\x15\x12\x1d\n\x18\x46N_ELEMENTWISE_SUM_FLOAT\x10\xbe\x15\x12\x1e\n\x19\x46N_ELEMENTWISE_SUM_DOUBLE\x10\xbf\x15\x12\x1f\n\x1a\x46N_ELEMENTWISE_SUM_NUMERIC\x10\xc0\x15\x12\"\n\x1d\x46N_ELEMENTWISE_SUM_BIGNUMERIC\x10\xc1\x15\x12 \n\x1b\x46N_ELEMENTWISE_SUM_INTERVAL\x10\xc2\x15\x12\x1d\n\x18\x46N_ELEMENTWISE_AVG_INT32\x10\xc3\x15\x12\x1d\n\x18\x46N_ELEMENTWISE_AVG_INT64\x10\xc4\x15\x12\x1e\n\x19\x46N_ELEMENTWISE_AVG_UINT32\x10\xc5\x15\x12\x1e\n\x19\x46N_ELEMENTWISE_AVG_UINT64\x10\xc6\x15\x12\x1d\n\x18\x46N_ELEMENTWISE_AVG_FLOAT\x10\xc7\x15\x12\x1e\n\x19\x46N_ELEMENTWISE_AVG_DOUBLE\x10\xc8\x15\x12\x1f\n\x1a\x46N_ELEMENTWISE_AVG_NUMERIC\x10\xc9\x15\x12\"\n\x1d\x46N_ELEMENTWISE_AVG_BIGNUMERIC\x10\xca\x15\x12 \n\x1b\x46N_ELEMENTWISE_AVG_INTERVAL\x10\xcb\x15\x12\x0f\n\nFN_COUNTIF\x10\xa3\x0b\x12 \n\x1b\x46N_KLL_QUANTILES_INIT_INT64\x10\xab\x0b\x12!\n\x1c\x46N_KLL_QUANTILES_INIT_UINT64\x10\xac\x0b\x12!\n\x1c\x46N_KLL_QUANTILES_INIT_DOUBLE\x10\xad\x0b\x12#\n\x1e\x46N_KLL_QUANTILES_MERGE_PARTIAL\x10\xae\x0b\x12!\n\x1c\x46N_KLL_QUANTILES_MERGE_INT64\x10\xaf\x0b\x12\"\n\x1d\x46N_KLL_QUANTILES_MERGE_UINT64\x10\xb0\x0b\x12\"\n\x1d\x46N_KLL_QUANTILES_MERGE_DOUBLE\x10\xb1\x0b\x12#\n\x1e\x46N_KLL_QUANTILES_EXTRACT_INT64\x10\xb2\x0b\x12$\n\x1f\x46N_KLL_QUANTILES_EXTRACT_UINT64\x10\xb3\x0b\x12$\n\x1f\x46N_KLL_QUANTILES_EXTRACT_DOUBLE\x10\xb4\x0b\x12\'\n\"FN_KLL_QUANTILES_MERGE_POINT_INT64\x10\xb5\x0b\x12(\n#FN_KLL_QUANTILES_MERGE_POINT_UINT64\x10\xb6\x0b\x12(\n#FN_KLL_QUANTILES_MERGE_POINT_DOUBLE\x10\xb7\x0b\x12)\n$FN_KLL_QUANTILES_EXTRACT_POINT_INT64\x10\xb8\x0b\x12*\n%FN_KLL_QUANTILES_EXTRACT_POINT_UINT64\x10\xb9\x0b\x12*\n%FN_KLL_QUANTILES_EXTRACT_POINT_DOUBLE\x10\xba\x0b\x12/\n*FN_KLL_QUANTILES_MERGE_RELATIVE_RANK_INT64\x10\xed\x15\x12\x30\n+FN_KLL_QUANTILES_MERGE_RELATIVE_RANK_UINT64\x10\xee\x15\x12\x30\n+FN_KLL_QUANTILES_MERGE_RELATIVE_RANK_DOUBLE\x10\xef\x15\x12\x31\n,FN_KLL_QUANTILES_EXTRACT_RELATIVE_RANK_INT64\x10\xe4\x19\x12\x32\n-FN_KLL_QUANTILES_EXTRACT_RELATIVE_RANK_UINT64\x10\xe5\x19\x12\x32\n-FN_KLL_QUANTILES_EXTRACT_RELATIVE_RANK_DOUBLE\x10\xe6\x19\x12\x12\n\rFN_DENSE_RANK\x10\xdc\x0b\x12\x0c\n\x07\x46N_RANK\x10\xdd\x0b\x12\x12\n\rFN_ROW_NUMBER\x10\xde\x0b\x12\x14\n\x0f\x46N_PERCENT_RANK\x10\xdf\x0b\x12\x11\n\x0c\x46N_CUME_DIST\x10\xe0\x0b\x12\r\n\x08\x46N_NTILE\x10\xe1\x0b\x12\x0c\n\x07\x46N_LEAD\x10\xe2\x0b\x12\x0b\n\x06\x46N_LAG\x10\xe3\x0b\x12\x13\n\x0e\x46N_FIRST_VALUE\x10\xe4\x0b\x12\x12\n\rFN_LAST_VALUE\x10\xe5\x0b\x12\x11\n\x0c\x46N_NTH_VALUE\x10\xe6\x0b\x12\x17\n\x12\x46N_PERCENTILE_CONT\x10\xe7\x0b\x12\x1f\n\x1a\x46N_PERCENTILE_CONT_NUMERIC\x10\xe9\x0b\x12\"\n\x1d\x46N_PERCENTILE_CONT_BIGNUMERIC\x10\xeb\x0b\x12\x17\n\x12\x46N_PERCENTILE_DISC\x10\xe8\x0b\x12\x1f\n\x1a\x46N_PERCENTILE_DISC_NUMERIC\x10\xea\x0b\x12\"\n\x1d\x46N_PERCENTILE_DISC_BIGNUMERIC\x10\xec\x0b\x12\x10\n\x0b\x46N_IS_FIRST\x10\xed\x0b\x12\x0f\n\nFN_IS_LAST\x10\xee\x0b\x12\x1f\n\x1a\x46N_BIT_CAST_INT32_TO_INT32\x10\xc4\x0c\x12 \n\x1b\x46N_BIT_CAST_UINT32_TO_INT32\x10\xc5\x0c\x12\x1f\n\x1a\x46N_BIT_CAST_INT64_TO_INT64\x10\xc6\x0c\x12 \n\x1b\x46N_BIT_CAST_UINT64_TO_INT64\x10\xc7\x0c\x12!\n\x1c\x46N_BIT_CAST_UINT32_TO_UINT32\x10\xc8\x0c\x12 \n\x1b\x46N_BIT_CAST_INT32_TO_UINT32\x10\xc9\x0c\x12!\n\x1c\x46N_BIT_CAST_UINT64_TO_UINT64\x10\xca\x0c\x12 \n\x1b\x46N_BIT_CAST_INT64_TO_UINT64\x10\xcb\x0c\x12\x14\n\x0f\x46N_SESSION_USER\x10\xcc\x0c\x12\x1c\n\x17\x46N_GENERATE_ARRAY_INT64\x10\xcd\x0c\x12\x1d\n\x18\x46N_GENERATE_ARRAY_UINT64\x10\xce\x0c\x12\x1e\n\x19\x46N_GENERATE_ARRAY_NUMERIC\x10\xd9\x0c\x12!\n\x1c\x46N_GENERATE_ARRAY_BIGNUMERIC\x10\x93\r\x12\x1d\n\x18\x46N_GENERATE_ARRAY_DOUBLE\x10\xcf\x0c\x12\x1b\n\x16\x46N_GENERATE_DATE_ARRAY\x10\xd0\x0c\x12 \n\x1b\x46N_GENERATE_TIMESTAMP_ARRAY\x10\xd1\x0c\x12\x15\n\x10\x46N_ARRAY_REVERSE\x10\xd5\x0c\x12\x14\n\x0f\x46N_RANGE_BUCKET\x10\x90\r\x12\x0c\n\x07\x46N_RAND\x10\xd2\x0c\x12\x15\n\x10\x46N_GENERATE_UUID\x10\x8f\r\x12\x10\n\x0b\x46N_NEW_UUID\x10\xe1\x14\x12\x14\n\x0f\x46N_JSON_EXTRACT\x10\xd3\x0c\x12\x19\n\x14\x46N_JSON_EXTRACT_JSON\x10\x94\r\x12\x1b\n\x16\x46N_JSON_EXTRACT_SCALAR\x10\xd4\x0c\x12 \n\x1b\x46N_JSON_EXTRACT_SCALAR_JSON\x10\x95\r\x12\x1a\n\x15\x46N_JSON_EXTRACT_ARRAY\x10\x91\r\x12\x1f\n\x1a\x46N_JSON_EXTRACT_ARRAY_JSON\x10\x9b\r\x12!\n\x1c\x46N_JSON_EXTRACT_STRING_ARRAY\x10\x98\r\x12&\n!FN_JSON_EXTRACT_STRING_ARRAY_JSON\x10\x9c\r\x12\x18\n\x13\x46N_JSON_QUERY_ARRAY\x10\x9d\r\x12\x1d\n\x18\x46N_JSON_QUERY_ARRAY_JSON\x10\x9e\r\x12\x18\n\x13\x46N_JSON_VALUE_ARRAY\x10\x9f\r\x12\x1d\n\x18\x46N_JSON_VALUE_ARRAY_JSON\x10\xa0\r\x12\x1c\n\x17\x46N_JSON_SUBSCRIPT_INT64\x10\x99\r\x12\x1d\n\x18\x46N_JSON_SUBSCRIPT_STRING\x10\x9a\r\x12\x16\n\x11\x46N_TO_JSON_STRING\x10\xd6\x0c\x12\x0f\n\nFN_TO_JSON\x10\xa1\r\x12\"\n\x1d\x46N_TO_JSON_UNSUPPORTED_FIELDS\x10\x9c\x0f\x12\x1e\n\x19\x46N_TO_JSON_PATH_AS_OBJECT\x10\xcd\x1a\x12\x31\n,FN_TO_JSON_UNSUPPORTED_FIELDS_PATH_AS_OBJECT\x10\xce\x1a\x12\x14\n\x0f\x46N_SAFE_TO_JSON\x10\x9d\x0f\x12\x12\n\rFN_JSON_QUERY\x10\xd7\x0c\x12\x17\n\x12\x46N_JSON_QUERY_JSON\x10\x96\r\x12\x12\n\rFN_JSON_VALUE\x10\xd8\x0c\x12\x17\n\x12\x46N_JSON_VALUE_JSON\x10\x97\r\x12\x12\n\rFN_PARSE_JSON\x10\xa2\r\x12\x1c\n\x17\x46N_FROM_PROTO_TIMESTAMP\x10\xda\x0c\x12\x17\n\x12\x46N_FROM_PROTO_DATE\x10\xdb\x0c\x12\x1e\n\x19\x46N_FROM_PROTO_TIME_OF_DAY\x10\xdc\x0c\x12\x19\n\x14\x46N_FROM_PROTO_DOUBLE\x10\xde\x0c\x12\x18\n\x13\x46N_FROM_PROTO_FLOAT\x10\xdf\x0c\x12\x18\n\x13\x46N_FROM_PROTO_INT64\x10\xe0\x0c\x12\x19\n\x14\x46N_FROM_PROTO_UINT64\x10\xe1\x0c\x12\x18\n\x13\x46N_FROM_PROTO_INT32\x10\xe2\x0c\x12\x19\n\x14\x46N_FROM_PROTO_UINT32\x10\xe3\x0c\x12\x17\n\x12\x46N_FROM_PROTO_BOOL\x10\xe4\x0c\x12\x18\n\x13\x46N_FROM_PROTO_BYTES\x10\xe5\x0c\x12\x19\n\x14\x46N_FROM_PROTO_STRING\x10\xe6\x0c\x12\x1b\n\x16\x46N_FROM_PROTO_DURATION\x10\xfc\x14\x12\'\n\"FN_FROM_PROTO_IDEMPOTENT_TIMESTAMP\x10\xe7\x0c\x12\"\n\x1d\x46N_FROM_PROTO_IDEMPOTENT_DATE\x10\xe8\x0c\x12\"\n\x1d\x46N_FROM_PROTO_IDEMPOTENT_TIME\x10\xe9\x0c\x12$\n\x1f\x46N_FROM_PROTO_IDEMPOTENT_DOUBLE\x10\xeb\x0c\x12#\n\x1e\x46N_FROM_PROTO_IDEMPOTENT_FLOAT\x10\xec\x0c\x12#\n\x1e\x46N_FROM_PROTO_IDEMPOTENT_INT64\x10\xed\x0c\x12$\n\x1f\x46N_FROM_PROTO_IDEMPOTENT_UINT64\x10\xee\x0c\x12#\n\x1e\x46N_FROM_PROTO_IDEMPOTENT_INT32\x10\xef\x0c\x12$\n\x1f\x46N_FROM_PROTO_IDEMPOTENT_UINT32\x10\xf0\x0c\x12\"\n\x1d\x46N_FROM_PROTO_IDEMPOTENT_BOOL\x10\xf1\x0c\x12#\n\x1e\x46N_FROM_PROTO_IDEMPOTENT_BYTES\x10\xf2\x0c\x12$\n\x1f\x46N_FROM_PROTO_IDEMPOTENT_STRING\x10\xf3\x0c\x12&\n!FN_FROM_PROTO_IDEMPOTENT_INTERVAL\x10\xfd\x14\x12\x1a\n\x15\x46N_TO_PROTO_TIMESTAMP\x10\xf4\x0c\x12\x15\n\x10\x46N_TO_PROTO_DATE\x10\xf5\x0c\x12\x15\n\x10\x46N_TO_PROTO_TIME\x10\xf6\x0c\x12\x17\n\x12\x46N_TO_PROTO_DOUBLE\x10\xf8\x0c\x12\x16\n\x11\x46N_TO_PROTO_FLOAT\x10\xf9\x0c\x12\x16\n\x11\x46N_TO_PROTO_INT64\x10\xfa\x0c\x12\x17\n\x12\x46N_TO_PROTO_UINT64\x10\xfb\x0c\x12\x16\n\x11\x46N_TO_PROTO_INT32\x10\xfc\x0c\x12\x17\n\x12\x46N_TO_PROTO_UINT32\x10\xfd\x0c\x12\x15\n\x10\x46N_TO_PROTO_BOOL\x10\xfe\x0c\x12\x16\n\x11\x46N_TO_PROTO_BYTES\x10\xff\x0c\x12\x17\n\x12\x46N_TO_PROTO_STRING\x10\x80\r\x12\x19\n\x14\x46N_TO_PROTO_INTERVAL\x10\x80\x15\x12%\n FN_TO_PROTO_IDEMPOTENT_TIMESTAMP\x10\x81\r\x12 \n\x1b\x46N_TO_PROTO_IDEMPOTENT_DATE\x10\x82\r\x12\'\n\"FN_TO_PROTO_IDEMPOTENT_TIME_OF_DAY\x10\x83\r\x12\"\n\x1d\x46N_TO_PROTO_IDEMPOTENT_DOUBLE\x10\x85\r\x12!\n\x1c\x46N_TO_PROTO_IDEMPOTENT_FLOAT\x10\x86\r\x12!\n\x1c\x46N_TO_PROTO_IDEMPOTENT_INT64\x10\x87\r\x12\"\n\x1d\x46N_TO_PROTO_IDEMPOTENT_UINT64\x10\x88\r\x12!\n\x1c\x46N_TO_PROTO_IDEMPOTENT_INT32\x10\x89\r\x12\"\n\x1d\x46N_TO_PROTO_IDEMPOTENT_UINT32\x10\x8a\r\x12 \n\x1b\x46N_TO_PROTO_IDEMPOTENT_BOOL\x10\x8b\r\x12!\n\x1c\x46N_TO_PROTO_IDEMPOTENT_BYTES\x10\x8c\r\x12\"\n\x1d\x46N_TO_PROTO_IDEMPOTENT_STRING\x10\x8d\r\x12$\n\x1f\x46N_TO_PROTO_IDEMPOTENT_DURATION\x10\x81\x15\x12\x1d\n\x18\x46N_PROTO_DEFAULT_IF_NULL\x10\x8e\r\x12#\n\x1e\x46N_ENUM_VALUE_DESCRIPTOR_PROTO\x10\x92\r\x12\x15\n\x10\x46N_NET_FORMAT_IP\x10\xa4\r\x12\x14\n\x0f\x46N_NET_PARSE_IP\x10\xa5\r\x12\x1c\n\x17\x46N_NET_FORMAT_PACKED_IP\x10\xa6\r\x12\x1b\n\x16\x46N_NET_PARSE_PACKED_IP\x10\xa7\r\x12\x15\n\x10\x46N_NET_IP_IN_NET\x10\xa8\r\x12\x14\n\x0f\x46N_NET_MAKE_NET\x10\xa9\r\x12\x10\n\x0b\x46N_NET_HOST\x10\xaa\r\x12\x16\n\x11\x46N_NET_REG_DOMAIN\x10\xab\r\x12\x19\n\x14\x46N_NET_PUBLIC_SUFFIX\x10\xac\r\x12\x1a\n\x15\x46N_NET_IP_FROM_STRING\x10\xad\r\x12\x1f\n\x1a\x46N_NET_SAFE_IP_FROM_STRING\x10\xae\r\x12\x18\n\x13\x46N_NET_IP_TO_STRING\x10\xaf\r\x12\x17\n\x12\x46N_NET_IP_NET_MASK\x10\xb0\r\x12\x14\n\x0f\x46N_NET_IP_TRUNC\x10\xb1\r\x12\x1b\n\x16\x46N_NET_IPV4_FROM_INT64\x10\xb2\r\x12\x19\n\x14\x46N_NET_IPV4_TO_INT64\x10\xb3\r\x12\x11\n\x0c\x46N_MD5_BYTES\x10\xec\x0e\x12\x12\n\rFN_MD5_STRING\x10\xed\x0e\x12\x12\n\rFN_SHA1_BYTES\x10\xee\x0e\x12\x13\n\x0e\x46N_SHA1_STRING\x10\xef\x0e\x12\x14\n\x0f\x46N_SHA256_BYTES\x10\xf0\x0e\x12\x15\n\x10\x46N_SHA256_STRING\x10\xf1\x0e\x12\x14\n\x0f\x46N_SHA512_BYTES\x10\xf2\x0e\x12\x15\n\x10\x46N_SHA512_STRING\x10\xf3\x0e\x12\x1e\n\x19\x46N_FARM_FINGERPRINT_BYTES\x10\xf4\x0e\x12\x1f\n\x1a\x46N_FARM_FINGERPRINT_STRING\x10\xf5\x0e\x12\x17\n\x12\x46N_KEYS_NEW_KEYSET\x10\xf6\x0e\x12#\n\x1e\x46N_KEYS_ADD_KEY_FROM_RAW_BYTES\x10\xf7\x0e\x12\x1a\n\x15\x46N_KEYS_ROTATE_KEYSET\x10\xf8\x0e\x12\x1a\n\x15\x46N_KEYS_KEYSET_LENGTH\x10\xf9\x0e\x12\x1b\n\x16\x46N_KEYS_KEYSET_TO_JSON\x10\xfa\x0e\x12\x1d\n\x18\x46N_KEYS_KEYSET_FROM_JSON\x10\xfb\x0e\x12,\n\'FN_KEYS_KEYSET_CHAIN_STRING_BYTES_BYTES\x10\x88\x0f\x12&\n!FN_KEYS_KEYSET_CHAIN_STRING_BYTES\x10\x89\x0f\x12\x1f\n\x1a\x46N_KEYS_NEW_WRAPPED_KEYSET\x10\x96\x0f\x12\"\n\x1d\x46N_KEYS_ROTATE_WRAPPED_KEYSET\x10\x97\x0f\x12\x1a\n\x15\x46N_KEYS_REWRAP_KEYSET\x10\x98\x0f\x12$\n\x1f\x46N_AEAD_ENVELOPE_ENCRYPT_STRING\x10\x84\x0f\x12#\n\x1e\x46N_AEAD_ENVELOPE_ENCRYPT_BYTES\x10\x85\x0f\x12$\n\x1f\x46N_AEAD_ENVELOPE_DECRYPT_STRING\x10\x86\x0f\x12#\n\x1e\x46N_AEAD_ENVELOPE_DECRYPT_BYTES\x10\x87\x0f\x12\x1b\n\x16\x46N_AEAD_ENCRYPT_STRING\x10\xfc\x0e\x12\x1a\n\x15\x46N_AEAD_ENCRYPT_BYTES\x10\xfd\x0e\x12\"\n\x1d\x46N_AEAD_ENCRYPT_STRUCT_STRING\x10\x8a\x0f\x12!\n\x1c\x46N_AEAD_ENCRYPT_STRUCT_BYTES\x10\x8b\x0f\x12\x1b\n\x16\x46N_AEAD_DECRYPT_STRING\x10\xfe\x0e\x12\x1a\n\x15\x46N_AEAD_DECRYPT_BYTES\x10\xff\x0e\x12\"\n\x1d\x46N_AEAD_DECRYPT_STRUCT_STRING\x10\x8c\x0f\x12!\n\x1c\x46N_AEAD_DECRYPT_STRUCT_BYTES\x10\x8d\x0f\x12$\n\x1f\x46N_DETERMINISTIC_ENCRYPT_STRING\x10\x8e\x0f\x12#\n\x1e\x46N_DETERMINISTIC_ENCRYPT_BYTES\x10\x8f\x0f\x12$\n\x1f\x46N_DETERMINISTIC_DECRYPT_STRING\x10\x90\x0f\x12#\n\x1e\x46N_DETERMINISTIC_DECRYPT_BYTES\x10\x91\x0f\x12+\n&FN_DETERMINISTIC_ENCRYPT_STRUCT_STRING\x10\x92\x0f\x12*\n%FN_DETERMINISTIC_ENCRYPT_STRUCT_BYTES\x10\x93\x0f\x12+\n&FN_DETERMINISTIC_DECRYPT_STRUCT_STRING\x10\x94\x0f\x12*\n%FN_DETERMINISTIC_DECRYPT_STRUCT_BYTES\x10\x95\x0f\x12\x15\n\x10\x46N_ST_GEOG_POINT\x10\xd0\x0f\x12\x14\n\x0f\x46N_ST_MAKE_LINE\x10\xd1\x0f\x12\x1a\n\x15\x46N_ST_MAKE_LINE_ARRAY\x10\xd2\x0f\x12\x17\n\x12\x46N_ST_MAKE_POLYGON\x10\xd3\x0f\x12 \n\x1b\x46N_ST_MAKE_POLYGON_ORIENTED\x10\xd4\x0f\x12\x17\n\x12\x46N_ST_INTERSECTION\x10\xd7\x0f\x12\x10\n\x0b\x46N_ST_UNION\x10\xd8\x0f\x12\x16\n\x11\x46N_ST_UNION_ARRAY\x10\xd9\x0f\x12\x15\n\x10\x46N_ST_DIFFERENCE\x10\xda\x0f\x12\x16\n\x11\x46N_ST_UNARY_UNION\x10\xdb\x0f\x12\x13\n\x0e\x46N_ST_CENTROID\x10\xdc\x0f\x12\x11\n\x0c\x46N_ST_BUFFER\x10\xdd\x0f\x12 \n\x1b\x46N_ST_BUFFER_WITH_TOLERANCE\x10\xde\x0f\x12\x13\n\x0e\x46N_ST_SIMPLIFY\x10\xdf\x0f\x12\x17\n\x12\x46N_ST_SNAP_TO_GRID\x10\xe0\x0f\x12\x18\n\x13\x46N_ST_CLOSEST_POINT\x10\xe1\x0f\x12\x13\n\x0e\x46N_ST_BOUNDARY\x10\xe2\x0f\x12\x15\n\x10\x46N_ST_CONVEXHULL\x10\x91\x10\x12\x17\n\x12\x46N_ST_EXTERIORRING\x10\x9e\x10\x12\x18\n\x13\x46N_ST_INTERIORRINGS\x10\x9f\x10\x12\x19\n\x14\x46N_ST_LINE_SUBSTRING\x10\xab\x10\x12!\n\x1c\x46N_ST_LINE_INTERPOLATE_POINT\x10\xac\x10\x12\x11\n\x0c\x46N_ST_EQUALS\x10\xe4\x0f\x12\x15\n\x10\x46N_ST_INTERSECTS\x10\xe5\x0f\x12\x13\n\x0e\x46N_ST_CONTAINS\x10\xe6\x0f\x12\x11\n\x0c\x46N_ST_COVERS\x10\xe7\x0f\x12\x13\n\x0e\x46N_ST_DISJOINT\x10\xe8\x0f\x12\x19\n\x14\x46N_ST_INTERSECTS_BOX\x10\xe9\x0f\x12\x12\n\rFN_ST_DWITHIN\x10\xea\x0f\x12\x11\n\x0c\x46N_ST_WITHIN\x10\xeb\x0f\x12\x14\n\x0f\x46N_ST_COVEREDBY\x10\xec\x0f\x12\x12\n\rFN_ST_TOUCHES\x10\xed\x0f\x12\x1c\n\x17\x46N_ST_HAUSDORFF_DWITHIN\x10\xaf\x10\x12\x13\n\x0e\x46N_ST_IS_EMPTY\x10\xee\x0f\x12\x18\n\x13\x46N_ST_IS_COLLECTION\x10\xef\x0f\x12\x14\n\x0f\x46N_ST_DIMENSION\x10\xf0\x0f\x12\x15\n\x10\x46N_ST_NUM_POINTS\x10\xf1\x0f\x12\x19\n\x14\x46N_ST_NUM_GEOMETRIES\x10\xf2\x0f\x12\x18\n\x13\x46N_ST_GEOMETRY_TYPE\x10\xf3\x0f\x12\x0f\n\nFN_ST_DUMP\x10\x90\x10\x12\x12\n\rFN_ST_POINT_N\x10\x9b\x10\x12\x16\n\x11\x46N_ST_START_POINT\x10\x9c\x10\x12\x14\n\x0f\x46N_ST_END_POINT\x10\x9d\x10\x12\x14\n\x0f\x46N_ST_IS_CLOSED\x10\xa6\x10\x12\x12\n\rFN_ST_IS_RING\x10\xa7\x10\x12\x16\n\x11\x46N_ST_DUMP_POINTS\x10\xa8\x10\x12\x11\n\x0c\x46N_ST_LENGTH\x10\xf8\x0f\x12\x14\n\x0f\x46N_ST_PERIMETER\x10\xf9\x0f\x12\x0f\n\nFN_ST_AREA\x10\xfa\x0f\x12\x13\n\x0e\x46N_ST_DISTANCE\x10\xfb\x0f\x12\x17\n\x12\x46N_ST_MAX_DISTANCE\x10\xfc\x0f\x12\x12\n\rFN_ST_AZIMUTH\x10\xa0\x10\x12\x10\n\x0b\x46N_ST_ANGLE\x10\xa1\x10\x12\x1c\n\x17\x46N_ST_LINE_LOCATE_POINT\x10\xa9\x10\x12\x1d\n\x18\x46N_ST_HAUSDORFF_DISTANCE\x10\xaa\x10\x12\x19\n\x14\x46N_ST_GEOG_FROM_TEXT\x10\x82\x10\x12\x1d\n\x18\x46N_ST_GEOG_FROM_TEXT_EXT\x10\x8c\x10\x12\x18\n\x13\x46N_ST_GEOG_FROM_KML\x10\x83\x10\x12\x1d\n\x18\x46N_ST_GEOG_FROM_GEO_JSON\x10\x84\x10\x12!\n\x1c\x46N_ST_GEOG_FROM_GEO_JSON_EXT\x10\x94\x10\x12\x18\n\x13\x46N_ST_GEOG_FROM_WKB\x10\x88\x10\x12\x1c\n\x17\x46N_ST_GEOG_FROM_WKB_HEX\x10\x98\x10\x12\x1c\n\x17\x46N_ST_GEOG_FROM_WKB_EXT\x10\xad\x10\x12 \n\x1b\x46N_ST_GEOG_FROM_WKB_HEX_EXT\x10\xae\x10\x12\x1b\n\x16\x46N_ST_GEOG_FROM_STRING\x10\x99\x10\x12\x1a\n\x15\x46N_ST_GEOG_FROM_BYTES\x10\x9a\x10\x12\x12\n\rFN_ST_AS_TEXT\x10\x85\x10\x12\x11\n\x0c\x46N_ST_AS_KML\x10\x86\x10\x12\x16\n\x11\x46N_ST_AS_GEO_JSON\x10\x87\x10\x12\x14\n\x0f\x46N_ST_AS_BINARY\x10\x89\x10\x12\x12\n\rFN_ST_GEOHASH\x10\x8a\x10\x12\"\n\x1d\x46N_ST_GEOG_POINT_FROM_GEOHASH\x10\x8b\x10\x12\x14\n\x0f\x46N_ST_UNION_AGG\x10\x8d\x10\x12\x10\n\x0b\x46N_ST_ACCUM\x10\x8e\x10\x12\x17\n\x12\x46N_ST_CENTROID_AGG\x10\x8f\x10\x12\x1c\n\x17\x46N_ST_NEAREST_NEIGHBORS\x10\x93\x10\x12\x11\n\x0c\x46N_ST_EXTENT\x10\xa3\x10\x12\x1a\n\x15\x46N_S2_COVERINGCELLIDS\x10\xa2\x10\x12\x1a\n\x15\x46N_S2_CELLIDFROMPOINT\x10\xa5\x10\x12\x0c\n\x07\x46N_ST_X\x10\x96\x10\x12\x0c\n\x07\x46N_ST_Y\x10\x97\x10\x12\x18\n\x13\x46N_ST_CLUSTERDBSCAN\x10\x92\x10\x12\x17\n\x12\x46N_ST_BOUNDING_BOX\x10\xa4\x10\x12\x12\n\rFN_ANON_COUNT\x10\x98\x11\x12\x17\n\x12\x46N_ANON_COUNT_STAR\x10\x99\x11\x12\x16\n\x11\x46N_ANON_SUM_INT64\x10\x9a\x11\x12\x17\n\x12\x46N_ANON_SUM_UINT64\x10\x9b\x11\x12\x17\n\x12\x46N_ANON_SUM_DOUBLE\x10\x9c\x11\x12\x18\n\x13\x46N_ANON_SUM_NUMERIC\x10\x9d\x11\x12\x17\n\x12\x46N_ANON_AVG_DOUBLE\x10\x9e\x11\x12\x18\n\x13\x46N_ANON_AVG_NUMERIC\x10\x9f\x11\x12\x1b\n\x16\x46N_ANON_VAR_POP_DOUBLE\x10\xa0\x11\x12!\n\x1c\x46N_ANON_VAR_POP_DOUBLE_ARRAY\x10\xa1\x11\x12\x1e\n\x19\x46N_ANON_STDDEV_POP_DOUBLE\x10\xa2\x11\x12$\n\x1f\x46N_ANON_STDDEV_POP_DOUBLE_ARRAY\x10\xa3\x11\x12#\n\x1e\x46N_ANON_PERCENTILE_CONT_DOUBLE\x10\xa4\x11\x12)\n$FN_ANON_PERCENTILE_CONT_DOUBLE_ARRAY\x10\xa5\x11\x12\'\n\"FN_ANON_SUM_WITH_REPORT_JSON_INT64\x10\xa6\x11\x12(\n#FN_ANON_SUM_WITH_REPORT_JSON_DOUBLE\x10\xa7\x11\x12(\n#FN_ANON_SUM_WITH_REPORT_JSON_UINT64\x10\xa8\x11\x12(\n#FN_ANON_SUM_WITH_REPORT_PROTO_INT64\x10\xa9\x11\x12)\n$FN_ANON_SUM_WITH_REPORT_PROTO_DOUBLE\x10\xaa\x11\x12)\n$FN_ANON_SUM_WITH_REPORT_PROTO_UINT64\x10\xab\x11\x12\x1d\n\x18\x46N_ANON_QUANTILES_DOUBLE\x10\xac\x11\x12#\n\x1e\x46N_ANON_QUANTILES_DOUBLE_ARRAY\x10\xad\x11\x12#\n\x1e\x46N_ANON_COUNT_WITH_REPORT_JSON\x10\xae\x11\x12$\n\x1f\x46N_ANON_COUNT_WITH_REPORT_PROTO\x10\xaf\x11\x12(\n#FN_ANON_COUNT_STAR_WITH_REPORT_JSON\x10\xb0\x11\x12)\n$FN_ANON_COUNT_STAR_WITH_REPORT_PROTO\x10\xb1\x11\x12.\n)FN_ANON_QUANTILES_DOUBLE_WITH_REPORT_JSON\x10\xb2\x11\x12/\n*FN_ANON_QUANTILES_DOUBLE_WITH_REPORT_PROTO\x10\xb3\x11\x12\x34\n/FN_ANON_QUANTILES_DOUBLE_ARRAY_WITH_REPORT_JSON\x10\xb4\x11\x12\x35\n0FN_ANON_QUANTILES_DOUBLE_ARRAY_WITH_REPORT_PROTO\x10\xb5\x11\x12(\n#FN_ANON_AVG_DOUBLE_WITH_REPORT_JSON\x10\xb6\x11\x12)\n$FN_ANON_AVG_DOUBLE_WITH_REPORT_PROTO\x10\xb7\x11\x12\"\n\x1d\x46N_DIFFERENTIAL_PRIVACY_COUNT\x10\xf0\x15\x12\'\n\"FN_DIFFERENTIAL_PRIVACY_COUNT_STAR\x10\xf1\x15\x12&\n!FN_DIFFERENTIAL_PRIVACY_SUM_INT64\x10\xf2\x15\x12\'\n\"FN_DIFFERENTIAL_PRIVACY_SUM_UINT64\x10\xf3\x15\x12\'\n\"FN_DIFFERENTIAL_PRIVACY_SUM_DOUBLE\x10\xf4\x15\x12(\n#FN_DIFFERENTIAL_PRIVACY_SUM_NUMERIC\x10\xf5\x15\x12\'\n\"FN_DIFFERENTIAL_PRIVACY_AVG_DOUBLE\x10\xf6\x15\x12(\n#FN_DIFFERENTIAL_PRIVACY_AVG_NUMERIC\x10\xf7\x15\x12+\n&FN_DIFFERENTIAL_PRIVACY_VAR_POP_DOUBLE\x10\xf8\x15\x12\x31\n,FN_DIFFERENTIAL_PRIVACY_VAR_POP_DOUBLE_ARRAY\x10\xf9\x15\x12.\n)FN_DIFFERENTIAL_PRIVACY_STDDEV_POP_DOUBLE\x10\xfa\x15\x12\x34\n/FN_DIFFERENTIAL_PRIVACY_STDDEV_POP_DOUBLE_ARRAY\x10\xfb\x15\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_PERCENTILE_CONT_DOUBLE\x10\xfc\x15\x12\x39\n4FN_DIFFERENTIAL_PRIVACY_PERCENTILE_CONT_DOUBLE_ARRAY\x10\xfd\x15\x12\x32\n-FN_DIFFERENTIAL_PRIVACY_SUM_REPORT_JSON_INT64\x10\xfe\x15\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_SUM_REPORT_JSON_DOUBLE\x10\xff\x15\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_SUM_REPORT_JSON_UINT64\x10\x80\x16\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_SUM_REPORT_PROTO_INT64\x10\x81\x16\x12\x34\n/FN_DIFFERENTIAL_PRIVACY_SUM_REPORT_PROTO_DOUBLE\x10\x82\x16\x12\x34\n/FN_DIFFERENTIAL_PRIVACY_SUM_REPORT_PROTO_UINT64\x10\x83\x16\x12-\n(FN_DIFFERENTIAL_PRIVACY_QUANTILES_DOUBLE\x10\x84\x16\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_QUANTILES_DOUBLE_ARRAY\x10\x85\x16\x12.\n)FN_DIFFERENTIAL_PRIVACY_COUNT_REPORT_JSON\x10\x86\x16\x12/\n*FN_DIFFERENTIAL_PRIVACY_COUNT_REPORT_PROTO\x10\x87\x16\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_COUNT_STAR_REPORT_JSON\x10\x88\x16\x12\x34\n/FN_DIFFERENTIAL_PRIVACY_COUNT_STAR_REPORT_PROTO\x10\x89\x16\x12\x39\n4FN_DIFFERENTIAL_PRIVACY_QUANTILES_DOUBLE_REPORT_JSON\x10\x8a\x16\x12:\n5FN_DIFFERENTIAL_PRIVACY_QUANTILES_DOUBLE_REPORT_PROTO\x10\x8b\x16\x12?\n:FN_DIFFERENTIAL_PRIVACY_QUANTILES_DOUBLE_ARRAY_REPORT_JSON\x10\x8c\x16\x12@\n;FN_DIFFERENTIAL_PRIVACY_QUANTILES_DOUBLE_ARRAY_REPORT_PROTO\x10\x8d\x16\x12\x33\n.FN_DIFFERENTIAL_PRIVACY_AVG_DOUBLE_REPORT_JSON\x10\x8e\x16\x12\x34\n/FN_DIFFERENTIAL_PRIVACY_AVG_DOUBLE_REPORT_PROTO\x10\x8f\x16\x12\x32\n-FN_DIFFERENTIAL_PRIVACY_APPROX_COUNT_DISTINCT\x10\x90\x16\x12>\n9FN_DIFFERENTIAL_PRIVACY_APPROX_COUNT_DISTINCT_REPORT_JSON\x10\x91\x16\x12?\n:FN_DIFFERENTIAL_PRIVACY_APPROX_COUNT_DISTINCT_REPORT_PROTO\x10\x92\x16\x12>\n9FN_DIFFERENTIAL_PRIVACY_INIT_FOR_DP_APPROX_COUNT_DISTINCT\x10\x93\x16\x12G\nBFN_DIFFERENTIAL_PRIVACY_MERGE_PARTIAL_FOR_DP_APPROX_COUNT_DISTINCT\x10\x94\x16\x12\x41\n<FN_DIFFERENTIAL_PRIVACY_EXTRACT_FOR_DP_APPROX_COUNT_DISTINCT\x10\x95\x16\x12M\nHFN_DIFFERENTIAL_PRIVACY_EXTRACT_FOR_DP_APPROX_COUNT_DISTINCT_REPORT_JSON\x10\x96\x16\x12N\nIFN_DIFFERENTIAL_PRIVACY_EXTRACT_FOR_DP_APPROX_COUNT_DISTINCT_REPORT_PROTO\x10\x97\x16\x12\x0f\n\nFN_FLATTEN\x10\xc4\x13\x12\x17\n\x12\x46N_ARRAY_AT_OFFSET\x10\xea\x01\x12\x18\n\x13\x46N_ARRAY_AT_ORDINAL\x10\xeb\x01\x12\x14\n\x0f\x46N_ARRAY_CONCAT\x10\xec\x01\x12\x17\n\x12\x46N_ARRAY_CONCAT_OP\x10\x84\x02\x12\x14\n\x0f\x46N_ARRAY_LENGTH\x10\xdc\x01\x12\x16\n\x11\x46N_ARRAY_TO_BYTES\x10\xee\x01\x12\x17\n\x12\x46N_ARRAY_TO_STRING\x10\xed\x01\x12\x12\n\rFN_MAKE_ARRAY\x10\xda\x01\x12\x1c\n\x17\x46N_SAFE_ARRAY_AT_OFFSET\x10\xef\x01\x12\x1d\n\x18\x46N_SAFE_ARRAY_AT_ORDINAL\x10\xf0\x01\x12\x19\n\x14\x46N_ARRAY_IS_DISTINCT\x10\xc5\x13\x12\x18\n\x13\x46N_PROTO_MAP_AT_KEY\x10\xc6\x13\x12\x1d\n\x18\x46N_SAFE_PROTO_MAP_AT_KEY\x10\xc7\x13\x12\x18\n\x13\x46N_PROTO_MODIFY_MAP\x10\xce\x13\x12\x14\n\x0f\x46N_ARRAY_FILTER\x10\xc8\x13\x12\x1f\n\x1a\x46N_ARRAY_FILTER_WITH_INDEX\x10\xc9\x13\x12\x17\n\x12\x46N_ARRAY_TRANSFORM\x10\xca\x13\x12\"\n\x1d\x46N_ARRAY_TRANSFORM_WITH_INDEX\x10\xcb\x13\x12\x1e\n\x19\x46N_PROTO_MAP_CONTAINS_KEY\x10\xcc\x13\x12\x16\n\x11\x46N_ARRAY_INCLUDES\x10\xcf\x13\x12\x1d\n\x18\x46N_ARRAY_INCLUDES_LAMBDA\x10\xd0\x13\x12\x1a\n\x15\x46N_ARRAY_INCLUDES_ANY\x10\xd1\x13\x12\x1a\n\x15\x46N_ARRAY_INCLUDES_ALL\x10\xd2\x13\x12\x13\n\x0e\x46N_ARRAY_FIRST\x10\xd3\x13\x12\x12\n\rFN_ARRAY_LAST\x10\xd4\x13\x12\x13\n\x0e\x46N_ARRAY_SLICE\x10\xd5\x13\x12\x17\n\x12\x46N_ARRAY_SUM_INT32\x10\xd6\x13\x12\x17\n\x12\x46N_ARRAY_SUM_INT64\x10\xd7\x13\x12\x18\n\x13\x46N_ARRAY_SUM_UINT32\x10\xd8\x13\x12\x18\n\x13\x46N_ARRAY_SUM_UINT64\x10\xd9\x13\x12\x17\n\x12\x46N_ARRAY_SUM_FLOAT\x10\xda\x13\x12\x18\n\x13\x46N_ARRAY_SUM_DOUBLE\x10\xdb\x13\x12\x19\n\x14\x46N_ARRAY_SUM_NUMERIC\x10\xdc\x13\x12\x1c\n\x17\x46N_ARRAY_SUM_BIGNUMERIC\x10\xdd\x13\x12\x1a\n\x15\x46N_ARRAY_SUM_INTERVAL\x10\xde\x13\x12\x17\n\x12\x46N_ARRAY_AVG_INT32\x10\xdf\x13\x12\x17\n\x12\x46N_ARRAY_AVG_INT64\x10\xe0\x13\x12\x18\n\x13\x46N_ARRAY_AVG_UINT32\x10\xe1\x13\x12\x18\n\x13\x46N_ARRAY_AVG_UINT64\x10\xe2\x13\x12\x17\n\x12\x46N_ARRAY_AVG_FLOAT\x10\xe3\x13\x12\x18\n\x13\x46N_ARRAY_AVG_DOUBLE\x10\xe4\x13\x12\x19\n\x14\x46N_ARRAY_AVG_NUMERIC\x10\xe5\x13\x12\x1c\n\x17\x46N_ARRAY_AVG_BIGNUMERIC\x10\xe6\x13\x12\x1a\n\x15\x46N_ARRAY_AVG_INTERVAL\x10\xe7\x13\x12\x14\n\x0f\x46N_ARRAY_OFFSET\x10\xe8\x13\x12\x15\n\x10\x46N_ARRAY_OFFSETS\x10\xe9\x13\x12\x12\n\rFN_ARRAY_FIND\x10\xea\x13\x12\x16\n\x11\x46N_ARRAY_FIND_ALL\x10\xeb\x13\x12\x1b\n\x16\x46N_ARRAY_OFFSET_LAMBDA\x10\xf4\x13\x12\x1c\n\x17\x46N_ARRAY_OFFSETS_LAMBDA\x10\xf5\x13\x12\x19\n\x14\x46N_ARRAY_FIND_LAMBDA\x10\xf6\x13\x12\x1d\n\x18\x46N_ARRAY_FIND_ALL_LAMBDA\x10\xf7\x13\x12\x11\n\x0c\x46N_ARRAY_MIN\x10\xec\x13\x12\x11\n\x0c\x46N_ARRAY_MAX\x10\xed\x13\x12\x17\n\x12\x46N_ARRAY_MAX_FLOAT\x10\xee\x13\x12\x18\n\x13\x46N_ARRAY_MAX_DOUBLE\x10\xef\x13\x12\x15\n\x10\x46N_ARRAY_FIRST_N\x10\xf0\x13\x12\x14\n\x0f\x46N_ARRAY_LAST_N\x10\xf1\x13\x12\x1c\n\x17\x46N_ARRAY_REMOVE_FIRST_N\x10\xf2\x13\x12\x1b\n\x16\x46N_ARRAY_REMOVE_LAST_N\x10\xf3\x13\x12\x1b\n\x16\x46N_ARRAY_ZIP_TWO_ARRAY\x10\xf8\x13\x12\"\n\x1d\x46N_ARRAY_ZIP_TWO_ARRAY_LAMBDA\x10\xf9\x13\x12\x1d\n\x18\x46N_ARRAY_ZIP_THREE_ARRAY\x10\xfb\x13\x12$\n\x1f\x46N_ARRAY_ZIP_THREE_ARRAY_LAMBDA\x10\xfc\x13\x12\x1c\n\x17\x46N_ARRAY_ZIP_FOUR_ARRAY\x10\xfe\x13\x12#\n\x1e\x46N_ARRAY_ZIP_FOUR_ARRAY_LAMBDA\x10\xff\x13\x12\x15\n\x10\x46N_JSON_TO_INT64\x10\xa8\x14\x12\x14\n\x0f\x46N_JSON_TO_BOOL\x10\xa9\x14\x12\x16\n\x11\x46N_JSON_TO_STRING\x10\xaa\x14\x12\x11\n\x0c\x46N_JSON_TYPE\x10\xab\x14\x12\x16\n\x11\x46N_JSON_TO_DOUBLE\x10\xac\x14\x12\x19\n\x14\x46N_JSON_LAX_TO_INT64\x10\xae\x14\x12\x18\n\x13\x46N_JSON_LAX_TO_BOOL\x10\xaf\x14\x12\x1a\n\x15\x46N_JSON_LAX_TO_STRING\x10\xb0\x14\x12\x1a\n\x15\x46N_JSON_LAX_TO_DOUBLE\x10\xb1\x14\x12\x12\n\rFN_JSON_ARRAY\x10\xb6\x14\x12\x13\n\x0e\x46N_JSON_OBJECT\x10\xb7\x14\x12\x1a\n\x15\x46N_JSON_OBJECT_ARRAYS\x10\xb8\x14\x12\x13\n\x0e\x46N_JSON_REMOVE\x10\xb9\x14\x12\x10\n\x0b\x46N_JSON_SET\x10\xba\x14\x12\x18\n\x13\x46N_JSON_STRIP_NULLS\x10\xbb\x14\x12\x19\n\x14\x46N_JSON_ARRAY_INSERT\x10\xbc\x14\x12\x19\n\x14\x46N_JSON_ARRAY_APPEND\x10\xbd\x14\x12\r\n\x08\x46N_APPLY\x10\xfe\x14\x12\r\n\x08\x46N_RANGE\x10\xad\x14\x12 \n\x1b\x46N_RANGE_IS_START_UNBOUNDED\x10\xd4\x16\x12\x1e\n\x19\x46N_RANGE_IS_END_UNBOUNDED\x10\xd6\x16\x12\x13\n\x0e\x46N_RANGE_START\x10\xd8\x16\x12\x11\n\x0c\x46N_RANGE_END\x10\xda\x16\x12\x16\n\x11\x46N_RANGE_OVERLAPS\x10\xdc\x16\x12\x17\n\x12\x46N_RANGE_INTERSECT\x10\xe0\x16\x12!\n\x1c\x46N_GENERATE_DATE_RANGE_ARRAY\x10\xe4\x16\x12%\n FN_GENERATE_DATETIME_RANGE_ARRAY\x10\xe5\x16\x12&\n!FN_GENERATE_TIMESTAMP_RANGE_ARRAY\x10\xe6\x16\x12\x1c\n\x17\x46N_RANGE_CONTAINS_RANGE\x10\xe7\x16\x12\x1e\n\x19\x46N_RANGE_CONTAINS_ELEMENT\x10\xe8\x16\x12$\n\x1f\x46N_COSINE_DISTANCE_DENSE_DOUBLE\x10\xa9\x12\x12#\n\x1e\x46N_COSINE_DISTANCE_DENSE_FLOAT\x10\xb1\x12\x12$\n\x1f\x46N_COSINE_DISTANCE_SPARSE_INT64\x10\xaa\x12\x12%\n FN_COSINE_DISTANCE_SPARSE_STRING\x10\xab\x12\x12%\n FN_APPROX_COSINE_DISTANCE_DOUBLE\x10\xb3\x12\x12$\n\x1f\x46N_APPROX_COSINE_DISTANCE_FLOAT\x10\xb4\x12\x12\x37\n2FN_APPROX_COSINE_DISTANCE_DOUBLE_WITH_JSON_OPTIONS\x10\xb5\x12\x12\x36\n1FN_APPROX_COSINE_DISTANCE_FLOAT_WITH_JSON_OPTIONS\x10\xb6\x12\x12\x38\n3FN_APPROX_COSINE_DISTANCE_DOUBLE_WITH_PROTO_OPTIONS\x10\xcd\x12\x12\x37\n2FN_APPROX_COSINE_DISTANCE_FLOAT_WITH_PROTO_OPTIONS\x10\xce\x12\x12\'\n\"FN_EUCLIDEAN_DISTANCE_DENSE_DOUBLE\x10\xac\x12\x12&\n!FN_EUCLIDEAN_DISTANCE_DENSE_FLOAT\x10\xb2\x12\x12\'\n\"FN_EUCLIDEAN_DISTANCE_SPARSE_INT64\x10\xad\x12\x12(\n#FN_EUCLIDEAN_DISTANCE_SPARSE_STRING\x10\xae\x12\x12(\n#FN_APPROX_EUCLIDEAN_DISTANCE_DOUBLE\x10\xb7\x12\x12\'\n\"FN_APPROX_EUCLIDEAN_DISTANCE_FLOAT\x10\xb8\x12\x12:\n5FN_APPROX_EUCLIDEAN_DISTANCE_DOUBLE_WITH_JSON_OPTIONS\x10\xb9\x12\x12\x39\n4FN_APPROX_EUCLIDEAN_DISTANCE_FLOAT_WITH_JSON_OPTIONS\x10\xba\x12\x12;\n6FN_APPROX_EUCLIDEAN_DISTANCE_DOUBLE_WITH_PROTO_OPTIONS\x10\xcf\x12\x12:\n5FN_APPROX_EUCLIDEAN_DISTANCE_FLOAT_WITH_PROTO_OPTIONS\x10\xd0\x12\x12\x15\n\x10\x46N_EDIT_DISTANCE\x10\xaf\x12\x12\x1b\n\x16\x46N_EDIT_DISTANCE_BYTES\x10\xb0\x12\x12\x19\n\x14\x46N_DOT_PRODUCT_INT64\x10\xbb\x12\x12\x19\n\x14\x46N_DOT_PRODUCT_FLOAT\x10\xbc\x12\x12\x1a\n\x15\x46N_DOT_PRODUCT_DOUBLE\x10\xbd\x12\x12 \n\x1b\x46N_APPROX_DOT_PRODUCT_INT64\x10\xbe\x12\x12 \n\x1b\x46N_APPROX_DOT_PRODUCT_FLOAT\x10\xbf\x12\x12!\n\x1c\x46N_APPROX_DOT_PRODUCT_DOUBLE\x10\xc0\x12\x12\x32\n-FN_APPROX_DOT_PRODUCT_INT64_WITH_JSON_OPTIONS\x10\xc1\x12\x12\x32\n-FN_APPROX_DOT_PRODUCT_FLOAT_WITH_JSON_OPTIONS\x10\xc2\x12\x12\x33\n.FN_APPROX_DOT_PRODUCT_DOUBLE_WITH_JSON_OPTIONS\x10\xc3\x12\x12\x33\n.FN_APPROX_DOT_PRODUCT_INT64_WITH_PROTO_OPTIONS\x10\xd1\x12\x12\x33\n.FN_APPROX_DOT_PRODUCT_FLOAT_WITH_PROTO_OPTIONS\x10\xd2\x12\x12\x34\n/FN_APPROX_DOT_PRODUCT_DOUBLE_WITH_PROTO_OPTIONS\x10\xd3\x12\x12 \n\x1b\x46N_MANHATTAN_DISTANCE_INT64\x10\xc4\x12\x12 \n\x1b\x46N_MANHATTAN_DISTANCE_FLOAT\x10\xc5\x12\x12!\n\x1c\x46N_MANHATTAN_DISTANCE_DOUBLE\x10\xc6\x12\x12\x15\n\x10\x46N_L1_NORM_INT64\x10\xc7\x12\x12\x15\n\x10\x46N_L1_NORM_FLOAT\x10\xc8\x12\x12\x16\n\x11\x46N_L1_NORM_DOUBLE\x10\xc9\x12\x12\x15\n\x10\x46N_L2_NORM_INT64\x10\xca\x12\x12\x15\n\x10\x46N_L2_NORM_FLOAT\x10\xcb\x12\x12\x16\n\x11\x46N_L2_NORM_DOUBLE\x10\xcc\x12\x12\x16\n\x11\x46N_IS_SOURCE_NODE\x10\xb2\x14\x12\x14\n\x0f\x46N_IS_DEST_NODE\x10\xb3\x14\x12\x1a\n\x15\x46N_SAME_GRAPH_ELEMENT\x10\xb4\x14\x12#\n\x1e\x46N_ALL_DIFFERENT_GRAPH_ELEMENT\x10\xbe\x14\x12\x17\n\x12\x46N_PROPERTY_EXISTS\x10\xb5\x14\x12\x18\n\x13\x46N_EQUAL_GRAPH_NODE\x10\xbf\x14\x12\x18\n\x13\x46N_EQUAL_GRAPH_EDGE\x10\xc0\x14\x12\x1c\n\x17\x46N_NOT_EQUAL_GRAPH_NODE\x10\xc1\x14\x12\x1c\n\x17\x46N_NOT_EQUAL_GRAPH_EDGE\x10\xc2\x14\x12\x1c\n\x17\x46N_LABELS_GRAPH_ELEMENT\x10\xdd\x14\x12$\n\x1f\x46N_PROPERTY_NAMES_GRAPH_ELEMENT\x10\xde\x14\x12\x1c\n\x17\x46N_TYPEOF_GRAPH_ELEMENT\x10\xdf\x14\x12 \n\x1b\x46N_ELEMENT_ID_GRAPH_ELEMENT\x10\xe2\x14\x12\x16\n\x11\x46N_SOURCE_NODE_ID\x10\xe3\x14\x12\x1b\n\x16\x46N_DESTINATION_NODE_ID\x10\xe4\x14\x12\x1f\n\x1a\x46N_ELEMENT_DEFINITION_NAME\x10\xe5\x14\x12\x13\n\x0e\x46N_PATH_LENGTH\x10\xe6\x14\x12\x12\n\rFN_PATH_NODES\x10\xe7\x14\x12\x12\n\rFN_PATH_EDGES\x10\xe8\x14\x12\x12\n\rFN_PATH_FIRST\x10\xe9\x14\x12\x11\n\x0c\x46N_PATH_LAST\x10\xea\x14\x12\x13\n\x0e\x46N_CONCAT_PATH\x10\xeb\x14\x12\x16\n\x11\x46N_CONCAT_OP_PATH\x10\xec\x14\x12\x13\n\x0e\x46N_PATH_CREATE\x10\xed\x14\x12\x12\n\rFN_IS_ACYCLIC\x10\xf0\x14\x12\x10\n\x0b\x46N_IS_TRAIL\x10\xf1\x14\x12\x11\n\x0c\x46N_IS_SIMPLE\x10\xf2\x14\x12\x1d\n\x18\x46N_UNCHECKED_CONCAT_PATH\x10\xee\x14\x12\x1d\n\x18\x46N_UNCHECKED_PATH_CREATE\x10\xef\x14\x12\x1f\n\x1a\x46N_DYNAMIC_PROPERTY_EQUALS\x10\xfb\x14\x12\x1a\n\x15\x46N_JSON_TO_BOOL_ARRAY\x10\xc3\x14\x12\x1e\n\x19\x46N_JSON_LAX_TO_BOOL_ARRAY\x10\xc4\x14\x12\x1d\n\x18\x46N_JSON_TO_FLOAT64_ARRAY\x10\xc5\x14\x12!\n\x1c\x46N_JSON_LAX_TO_FLOAT64_ARRAY\x10\xc6\x14\x12\x1b\n\x16\x46N_JSON_TO_INT64_ARRAY\x10\xc7\x14\x12\x1f\n\x1a\x46N_JSON_LAX_TO_INT64_ARRAY\x10\xc8\x14\x12\x1c\n\x17\x46N_JSON_TO_STRING_ARRAY\x10\xc9\x14\x12 \n\x1b\x46N_JSON_LAX_TO_STRING_ARRAY\x10\xca\x14\x12\x17\n\x12\x46N_JSON_TO_FLOAT32\x10\xcb\x14\x12\x1b\n\x16\x46N_JSON_LAX_TO_FLOAT32\x10\xcc\x14\x12\x1d\n\x18\x46N_JSON_TO_FLOAT32_ARRAY\x10\xcd\x14\x12!\n\x1c\x46N_JSON_LAX_TO_FLOAT32_ARRAY\x10\xce\x14\x12\x15\n\x10\x46N_JSON_TO_INT32\x10\xcf\x14\x12\x19\n\x14\x46N_JSON_LAX_TO_INT32\x10\xd0\x14\x12\x1b\n\x16\x46N_JSON_TO_INT32_ARRAY\x10\xd1\x14\x12\x1f\n\x1a\x46N_JSON_LAX_TO_INT32_ARRAY\x10\xd2\x14\x12\x16\n\x11\x46N_JSON_TO_UINT32\x10\xd3\x14\x12\x1a\n\x15\x46N_JSON_LAX_TO_UINT32\x10\xd4\x14\x12\x1c\n\x17\x46N_JSON_TO_UINT32_ARRAY\x10\xd5\x14\x12 \n\x1b\x46N_JSON_LAX_TO_UINT32_ARRAY\x10\xd6\x14\x12\x16\n\x11\x46N_JSON_TO_UINT64\x10\xd7\x14\x12\x1a\n\x15\x46N_JSON_LAX_TO_UINT64\x10\xd8\x14\x12\x1c\n\x17\x46N_JSON_TO_UINT64_ARRAY\x10\xd9\x14\x12 \n\x1b\x46N_JSON_LAX_TO_UINT64_ARRAY\x10\xda\x14\x12\x15\n\x10\x46N_JSON_CONTAINS\x10\xdb\x14\x12\x11\n\x0c\x46N_JSON_KEYS\x10\xe0\x14\x12\x14\n\x0f\x46N_JSON_FLATTEN\x10\xff\x14\x12\x16\n\x11\x46N_MAP_FROM_ARRAY\x10\xb8\x17\x12\x1a\n\x15\x46N_MAP_ENTRIES_SORTED\x10\xb9\x17\x12\x1c\n\x17\x46N_MAP_ENTRIES_UNSORTED\x10\xba\x17\x12\x0f\n\nFN_MAP_GET\x10\xbb\x17\x12\x15\n\x10\x46N_MAP_SUBSCRIPT\x10\xbc\x17\x12\x1e\n\x19\x46N_MAP_SUBSCRIPT_WITH_KEY\x10\xbd\x17\x12\x18\n\x13\x46N_MAP_CONTAINS_KEY\x10\xbe\x17\x12\x17\n\x12\x46N_MAP_KEYS_SORTED\x10\xbf\x17\x12\x19\n\x14\x46N_MAP_KEYS_UNSORTED\x10\xc0\x17\x12\x19\n\x14\x46N_MAP_VALUES_SORTED\x10\xc1\x17\x12\x1b\n\x16\x46N_MAP_VALUES_UNSORTED\x10\xc2\x17\x12 \n\x1b\x46N_MAP_VALUES_SORTED_BY_KEY\x10\xc3\x17\x12\x11\n\x0c\x46N_MAP_EMPTY\x10\xc4\x17\x12\x12\n\rFN_MAP_INSERT\x10\xc5\x17\x12\x1d\n\x18\x46N_MAP_INSERT_OR_REPLACE\x10\xc6\x17\x12\x1c\n\x17\x46N_MAP_REPLACE_KV_PAIRS\x10\xc7\x17\x12\'\n\"FN_MAP_REPLACE_K_REPEATED_V_LAMBDA\x10\xc8\x17\x12\x17\n\x12\x46N_MAP_CARDINALITY\x10\xc9\x17\x12\x12\n\rFN_MAP_DELETE\x10\xca\x17\x12\x12\n\rFN_MAP_FILTER\x10\xcb\x17\x12#\n\x1e\x46N_MAP_SAFE_SUBSCRIPT_WITH_KEY\x10\xcc\x17\x12\x0b\n\x06\x46N_AGG\x10\x9c\x18\x12\x11\n\x0c\x46N_FIRST_AGG\x10\x80\x19\x12\x10\n\x0b\x46N_LAST_AGG\x10\x81\x19\x12\x14\n\x0f\x46N_MATCH_NUMBER\x10\x82\x19\x12\x18\n\x13\x46N_MATCH_ROW_NUMBER\x10\x83\x19\x12\x12\n\rFN_CLASSIFIER\x10\x84\x19\x12\x0c\n\x07\x46N_NEXT\x10\x85\x19\x12\x0c\n\x07\x46N_PREV\x10\x86\x19\x12 \n\x1b\x46N_ZSTD_COMPRESS_FROM_BYTES\x10\x82\x15\x12!\n\x1c\x46N_ZSTD_COMPRESS_FROM_STRING\x10\x83\x15\x12 \n\x1b\x46N_ZSTD_DECOMPRESS_TO_BYTES\x10\x84\x15\x12!\n\x1c\x46N_ZSTD_DECOMPRESS_TO_STRING\x10\x85\x15\x12\x19\n\x14\x46N_VECTOR_SEARCH_TVF\x10\xa0\x1f\x12\x0e\n\tFN_TUMBLE\x10\xa1\x1f\x12\x0b\n\x06\x46N_HOP\x10\xa2\x1f\x12\x1f\n\x1a\x46N_TUMBLE_NO_TIMESTAMP_COL\x10\xa3\x1f\x12\x1c\n\x17\x46N_HOP_NO_TIMESTAMP_COL\x10\xa4\x1f\"\x06\x08\x80\x0f\x10\x80\x0f\"\x06\x08\x81\x0f\x10\x81\x0f\"\x06\x08\x82\x0f\x10\x82\x0f\"\x06\x08\x83\x0f\x10\x83\x0f\"\x06\x08\xfa\x13\x10\xfa\x13\"\x06\x08\xfd\x13\x10\xfd\x13\"\x06\x08\x80\x14\x10\x80\x14\"\x06\x08\xd5\x16\x10\xd5\x16\"\x06\x08\xd7\x16\x10\xd7\x16\"\x06\x08\xd9\x16\x10\xd9\x16\"\x06\x08\xdb\x16\x10\xdb\x16\"\x06\x08\xdd\x16\x10\xdd\x16\"\x06\x08\xde\x16\x10\xde\x16\"\x06\x08\xdf\x16\x10\xdf\x16\"\x06\x08\xe1\x16\x10\xe1\x16\"\x06\x08\xe2\x16\x10\xe2\x16\"\x06\x08\xe3\x16\x10\xe3\x16\"\x06\x08\xdc\x14\x10\xdc\x14*\x15\x46N_KMS_ENCRYPT_STRING*\x14\x46N_KMS_ENCRYPT_BYTES*\x15\x46N_KMS_DECRYPT_STRING*\x14\x46N_KMS_DECRYPT_BYTES*\x18\x46N_TO_JSON_GRAPH_ELEMENTB%\n\x12\x63om.google.zetasqlB\x0fZetaSQLFunction')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.builtin_function_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\017ZetaSQLFunction'
  _globals['_FUNCTIONSIGNATUREID']._serialized_start=52
  _globals['_FUNCTIONSIGNATUREID']._serialized_end=34145
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ArrayFindEnums(_message.Message):
    __slots__ = ()
    class ArrayFindMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ARRAY_FIND_MODE_INVALID: _ClassVar[ArrayFindEnums.ArrayFindMode]
        FIRST: _ClassVar[ArrayFindEnums.ArrayFindMode]
        LAST: _ClassVar[ArrayFindEnums.ArrayFindMode]
    ARRAY_FIND_MODE_INVALID: ArrayFindEnums.ArrayFindMode
    FIRST: ArrayFindEnums.ArrayFindMode
    LAST: ArrayFindEnums.ArrayFindMode
    def __init__(self) -> None: ...
